/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_ko.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_ko.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_ko(DocIntf *doc)
{
  doc->setHeader(
              "이 파일은 프로젝트에 대해 문서화 시스템 Doxygen (www.doxygen.org) 에서 사용할 설정을 설명합니다.\n"
              "\n"
              "이중 해시(##) 뒤의 모든 텍스트는 주석으로 간주되어 앞에 있는 태그 앞에 배치됩니다.\n"
              "\n"
              "단일 해시(#) 뒤의 모든 텍스트는 주석으로 간주되어 무시됩니다. 형식은 다음과 같습니다:\n"
              "TAG = value [value, ...]\n"
              "목록의 경우, 다음을 사용하여 항목을 추가할 수도 있습니다:\n"
              "TAG += value [value, ...]\n"
              "공백을 포함하는 값은 따옴표(\" \")로 묶어야 합니다.\n"
              "\n"
              "참고:\n"
              "\n"
              "Doxygen을 사용하여 사용된 설정 파일을 템플릿 설정 파일과 비교합니다:\n"
              "doxygen -x [configFile]\n"
              "환경 변수나 CMake 형식의 대체 변수를 바꾸지 않고, Doxygen을 사용하여 사용된 설정 파일을 템플릿 설정 파일과 비교합니다:\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "이 태그는 구성 파일에서 이 태그 이후에 오는 모든 문자에 사용되는 인코딩을 지정합니다. 기본값은 UTF-8이며, 이 태그가 처음 나타나기\n"
              "전의 모든 텍스트에도 사용되는 인코딩입니다. Doxygen은 트랜스코딩을 위해 libiconv(또는 libc 에 내장된 iconv)를\n"
              "사용합니다. 가능한 인코딩 목록은 https://www.gnu.org/software/libiconv/을 참조하세요.\n"
              "기본값은 UTF-8입니다."
          );
  doc->add(
              "PROJECT_NAME",
              "PROJECT_NAME 태그는 문서가 생성되는 프로젝트를 식별하는 단일 단어(또는 Doxywizard를 사용하지 않는 경우 큰따옴표로 묶인\n"
              "일련의 단어)입니다. 이 이름은 생성된 대부분의 페이지의 제목과 몇몇 다른 곳에서 사용됩니다.\n"
              "기본값은 My Project입니다."
          );
  doc->add(
              "PROJECT_NUMBER",
              "PROJECT_NUMBER 태그를 사용하여 프로젝트 번호 또는 개정 번호를 입력할 수 있습니다. 이는 생성된 문서를 보관하거나 버전 관리\n"
              "시스템이 사용되는 경우에 유용합니다."
          );
  doc->add(
              "PROJECT_BRIEF",
              "PROJECT_BRIEF 태그를 사용하여 각 페이지 상단에 표시되는 프로젝트의 선택적 한 줄 설명을 제공할 수 있으며, 독자에게 프로젝트의\n"
              "목적을 간략히 전달합니다. 설명은 짧아야 합니다."
          );
  doc->add(
              "PROJECT_LOGO",
              "PROJECT_LOGO 태그를 사용하여 문서에 포함될 로고 또는 아이콘을 지정할 수 있습니다. 로고의 최대 높이는 55픽셀을 초과해서는 안\n"
              "되며, 최대 너비는 200픽셀을 초과해서는 안 됩니다. Doxygen은 로고를 출력 디렉터리에 복사합니다."
          );
  doc->add(
              "PROJECT_ICON",
              "PROJECT_ICON 태그를 사용하여 HTML 문서를 표시할 때 탭에 포함될 아이콘을 지정할 수 있습니다. Doxygen은 로고를 출력\n"
              "디렉터리에 복사합니다."
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "OUTPUT_DIRECTORY 태그는 생성된 문서가 기록될 경로(상대 또는 절대)를 지정하는 데 사용됩니다. 상대 경로가 입력되면\n"
              "Doxygen이 시작된 위치에서의 상대 경로가 됩니다. 비워 두면 현재 디렉터리가 사용됩니다."
          );
  doc->add(
              "CREATE_SUBDIRS",
              "CREATE_SUBDIRS 태그가 YES 로 설정되면 Doxygen은 각 출력 형식의 출력 디렉터리 아래에 최대 4096개의 하위\n"
              "디렉터리(2레벨)를 생성하고 생성된 파일을 이러한 디렉터리에 분산시킵니다. 이 옵션을 활성화하면 Doxygen에 많은 소스 파일을 공급할 때\n"
              "편리합니다. 모든 생성 파일을 동일한 디렉터리에 두면 파일 시스템 성능 문제가 발생할 수 있습니다. 하위 디렉터리 수를 제어하려면\n"
              "CREATE_SUBDIRS_LEVEL 을 조정하세요.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "CREATE_SUBDIRS 태그가 YES 로 설정된 경우 생성되는 하위 디렉터리 수를 제어합니다. 레벨 0은 16개 디렉터리를 나타내며,\n"
              "레벨이 증가할 때마다 디렉터리 수가 두 배가 되어 레벨 8에서 4096개 디렉터리가 됩니다. 이것이 기본값이자 최대값입니다. 하위 디렉터리는\n"
              "2레벨로 구성되며, 첫 번째 레벨은 항상 16개 디렉터리의 고정된 수를 가집니다.\n"
              "최소값: 0, 최대값: 8, 기본값: 8.\n"
              "이 태그는 태그 CREATE_SUBDIRS을 YES로 설정해야 합니다."
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "ALLOW_UNICODE_NAMES 태그가 YES 로 설정되면 Doxygen은 생성된 파일 이름에 비ASCII 문자가 나타나는 것을\n"
              "허용합니다. NO 로 설정되면 비ASCII 문자가 이스케이프됩니다. 예를 들어, 유니코드 U+3044의 경우 _xE3_x81_x84가\n"
              "사용됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "OUTPUT_LANGUAGE 태그는 Doxygen에 의해 생성되는 모든 문서가 작성되는 언어를 지정하는 데 사용됩니다. Doxygen은 이\n"
              "정보를 사용하여 적절한 언어로 모든 고정 문자열 출력을 생성합니다.\n"
              "가능한 값:Afrikaans, Arabic, Armenian, Brazilian, Bulgarian, Catalan, Chinese,\n"
              "Chinese-Traditional, Croatian, Czech, Danish, Dutch, English (미국), Esperanto,\n"
              "Farsi (페르시아어), Finnish, French, German, Greek, Hindi, Hungarian, Indonesian,\n"
              "Italian, Japanese, Japanese-en (영어 메시지가 포함된 일본어), Korean, Korean-en (영어 메시지가\n"
              "포함된 한국어), Latvian, Lithuanian, Macedonian, Norwegian, Persian (파르시어), Polish,\n"
              "Portuguese, Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene,\n"
              "Spanish, Swedish, Turkish, Ukrainian그리고Vietnamese.\n"
              "기본값은 English입니다."
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "BRIEF_MEMBER_DESC 태그가 YES 로 설정되면 Doxygen은 파일 및 클래스 문서에 나열된 멤버 뒤에 간결한 멤버 설명을\n"
              "포함합니다(Javadoc 과 유사). 이를 비활성화하려면 NO 로 설정하세요.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "REPEAT_BRIEF",
              "REPEAT_BRIEF 태그가 YES 로 설정되면 Doxygen은 멤버 또는 함수의 간결한 설명을 상세 설명 앞에 추가합니다.\n"
              "\n"
              "참고: HIDE_UNDOC_MEMBERS와 BRIEF_MEMBER_DESC가 모두 NO 로 설정되면 간결한 설명이 완전히 억제됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "이 태그는 다양한 목록의 텍스트를 형성하기 위해 사용되는 준지능적 간결 설명 약어를 구현합니다. 이 목록의 각 문자열이 간결한 설명의 선행\n"
              "텍스트로 발견되면 텍스트에서 제거되고 전체 목록 처리 후의 결과가 주석이 달린 텍스트로 사용됩니다. 그렇지 않으면 간결한 설명이 그대로\n"
              "사용됩니다. 비워 두면 다음 값이 사용됩니다($name은 엔티티의 이름으로 자동 교체됨):The $name class, The $name\n"
              "widget, The $name file, is, provides, specifies, contains, represents, a,\n"
              "an그리고the."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "ALWAYS_DETAILED_SEC 와 REPEAT_BRIEF 태그가 모두 YES 로 설정되면 Doxygen은 간결한 설명만 있는 경우에도\n"
              "상세 섹션을 생성합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "INLINE_INHERITED_MEMB 태그가 YES 로 설정되면 Doxygen은 클래스의 문서에 상속된 모든 멤버를 일반 클래스 멤버인\n"
              "것처럼 표시합니다. 기본 클래스의 생성자, 소멸자 및 할당 연산자는 표시되지 않습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "FULL_PATH_NAMES",
              "FULL_PATH_NAMES 태그가 YES 로 설정되면 Doxygen은 파일 목록과 헤더 파일의 파일 이름 앞에 전체 경로를 추가합니다.\n"
              "NO 로 설정되면 파일 이름을 고유하게 만드는 가장 짧은 경로가 사용됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "STRIP_FROM_PATH",
              "STRIP_FROM_PATH 태그를 사용하여 경로의 사용자 정의 부분을 제거할 수 있습니다. 제거는 지정된 문자열 중 하나가 경로의 왼쪽\n"
              "부분과 일치하는 경우에만 수행됩니다. 이 태그를 사용하여 파일 목록에 상대 경로를 표시할 수 있습니다. 비워 두면 Doxygen이 실행되는\n"
              "디렉터리가 제거할 경로로 사용됩니다.\n"
              "\n"
              "여기에 절대 경로를 지정할 수 있지만, Doxygen이 시작되는 디렉터리에서의 상대 경로도 지정할 수 있습니다.\n"
              "이 태그는 태그 FULL_PATH_NAMES을 YES로 설정해야 합니다."
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "STRIP_FROM_INC_PATH 태그를 사용하여 클래스 문서에서 언급된 경로의 사용자 정의 부분을 제거할 수 있습니다. 이는 클래스를\n"
              "사용하기 위해 어떤 헤더 파일을 포함해야 하는지 독자에게 알립니다. 비워 두면 클래스 정의를 포함하는 헤더 파일의 이름만 사용됩니다. 그렇지\n"
              "않으면 일반적으로 -I 플래그를 사용하여 컴파일러에 전달되는 포함 경로 목록을 지정해야 합니다."
          );
  doc->add(
              "SHORT_NAMES",
              "SHORT_NAMES 태그가 YES 로 설정되면 Doxygen은 훨씬 짧은(그러나 읽기 어려운) 파일 이름을 생성합니다. 이는 DOS,\n"
              "Mac, CD-ROM과 같이 파일 시스템이 긴 이름을 지원하지 않는 경우에 편리합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "JAVADOC_AUTOBRIEF 태그가 YES 로 설정되면 Doxygen은 Javadoc 스타일 주석의 첫 번째 줄(첫 번째 마침표,\n"
              "물음표 또는 느낌표까지)을 간결한 설명으로 해석합니다. NO 로 설정되면 Javadoc 스타일은 일반 Qt 스타일 주석과 유사하게\n"
              "작동합니다(따라서 간결한 설명에는 명시적인 @brief 명령이 필요함).\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "JAVADOC_BANNER",
              "JAVADOC_BANNER 태그가 YES 로 설정되면 Doxygen은\n"
              "/***************\n"
              "와 같은 줄을 Javadoc 스타일 주석 \"배너\"의 시작으로 해석합니다. NO 로 설정되면 Javadoc 스타일은 일반 주석처럼 작동하며\n"
              "Doxygen은 이를 해석하지 않습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "QT_AUTOBRIEF",
              "QT_AUTOBRIEF 태그가 YES 로 설정되면 Doxygen은 Qt 스타일 주석의 첫 번째 줄(첫 번째 마침표, 물음표 또는\n"
              "느낌표까지)을 간결한 설명으로 해석합니다. NO 로 설정되면 Qt 스타일은 일반 Qt 스타일 주석과 유사하게 작동합니다(따라서 간결한\n"
              "설명에는 명시적인 \\brief 명령이 필요함).\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "MULTILINE_CPP_IS_BRIEF 태그를 YES 로 설정하면 Doxygen은 여러 줄 C++ 특수 주석 블록(즉, //! 또는\n"
              "/// 주석 블록)을 간결한 설명으로 처리합니다. 이것이 이전 기본 동작이었습니다. 새로운 기본값은 여러 줄 C++ 주석 블록을 상세\n"
              "설명으로 처리하는 것입니다. 이전 동작을 선호하는 경우 이 태그를 YES 로 설정하세요.\n"
              "\n"
              "이 태그를 YES 로 설정하면 Rational Rose 주석이 인식되지 않는다는 점에도 유의하세요.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "기본적으로 Python docstring은 미리 형식화된 텍스트로 표시되며 Doxygen의 특수 명령을 사용할 수 없습니다.\n"
              "PYTHON_DOCSTRING 을 NO 로 설정하면 Doxygen의 특수 명령을 사용할 수 있으며 docstring 문서 블록의 내용이\n"
              "Doxygen 문서로 표시됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "INHERIT_DOCS",
              "INHERIT_DOCS 태그가 YES 로 설정되면 문서화되지 않은 멤버는 재구현하는 문서화된 멤버로부터 문서를 상속받습니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "SEPARATE_MEMBER_PAGES 태그가 YES 로 설정되면 Doxygen은 각 멤버에 대한 새 페이지를 생성합니다. NO 로\n"
              "설정되면 멤버의 문서는 이를 포함하는 파일/클래스/네임스페이스의 일부가 됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "TAB_SIZE",
              "TAB_SIZE 태그를 사용하여 탭의 공백 수를 설정할 수 있습니다. Doxygen은 이 값을 사용하여 코드 조각의 탭을 공백으로\n"
              "대체합니다.\n"
              "최소값: 1, 최대값: 16, 기본값: 4."
          );
  doc->add(
              "ALIASES",
              "이 태그를 사용하여 문서에서 명령으로 작동하는 여러 별칭을 지정할 수 있습니다. 별칭의 형식은 다음과 같습니다:\n"
              "name=value\n"
              "예를 들어,\n"
              "\"sideeffect=@par Side Effects:^^\"\n"
              "를 추가하면 문서에 \\sideeffect(또는 @sideeffect) 명령을 배치할 수 있으며, \"Side Effects:\"라는 제목의\n"
              "사용자 정의 단락이 생성됩니다. 별칭의 값 부분에 \\n을 넣어 줄 바꿈을 삽입할 수 없습니다(결과 출력에서). 별칭의 값 부분에 ^^를\n"
              "넣으면 원본 파일에 물리적 줄 바꿈이 있는 것처럼 줄 바꿈을 삽입할 수 있습니다.별칭의 값 부분에 리터럴 {, } 또는 ,가 필요한 경우\n"
              "백슬래시(\\)를 사용하여 이스케이프해야 합니다. 이로 인해 \\{ 및 \\} 명령과 충돌이 발생할 수 있습니다. 이러한 명령의 경우 @{ 및\n"
              "@} 버전을 사용하거나 이중 이스케이프(\\\\{ 및 \\\\})를 사용하는 것이 좋습니다."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "OPTIMIZE_OUTPUT_FOR_C 태그를 YES 로 설정하면 프로젝트가 C 소스로만 구성된 경우 Doxygen은 C에 더 적합한\n"
              "출력을 생성합니다. 예를 들어, 사용되는 이름의 일부가 다릅니다. 모든 멤버의 목록은 생략됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "OPTIMIZE_OUTPUT_JAVA 태그를 YES 로 설정하면 프로젝트가 Java 또는 Python 소스로만 구성된 경우 Doxygen은\n"
              "해당 언어에 더 적합한 출력을 생성합니다. 예를 들어, 네임스페이스가 패키지로 표시되고 정규화된 범위가 다르게 보입니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "OPTIMIZE_FOR_FORTRAN 태그를 YES 로 설정하면 프로젝트가 Fortran 소스로 구성된 경우 Doxygen은\n"
              "Fortran에 적합한 출력을 생성합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "OPTIMIZE_OUTPUT_VHDL 태그를 YES 로 설정하면 프로젝트가 VHDL 소스로 구성된 경우 Doxygen은 VHDL에 적합한\n"
              "출력을 생성합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "OPTIMIZE_OUTPUT_SLICE 태그를 YES 로 설정하면 프로젝트가 Slice 소스로만 구성된 경우 Doxygen은 해당 언어에\n"
              "더 적합한 출력을 생성합니다. 예를 들어, 네임스페이스가 모듈로 표시되고 유형이 더 많은 그룹으로 분리됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen은 구문 분석하는 파일의 확장자에 따라 사용할 파서를 선택합니다. 이 태그를 사용하여 특정 확장자에 사용할 파서를 할당할 수\n"
              "있습니다. Doxygen에는 기본 제공 매핑이 있지만 이 태그를 사용하여 재정의하거나 확장할 수 있습니다. 형식은\n"
              "ext=language이며, ext는 파일 확장자, language는 Doxygen이 지원하는 파서 중 하나입니다: IDL, Java,\n"
              "JavaScript, Csharp(C#), C, C++, Lex, D, PHP, md(Markdown), Objective-C,\n"
              "Python, Slice, VHDL, Fortran(고정 형식 Fortran: FortranFixed, 자유 형식 Fortran:\n"
              "FortranFree, 알 수 없는 형식 Fortran: Fortran. 후자의 경우 파서는 코드가 고정 형식인지 자유 형식인지 추측하려고\n"
              "시도합니다. 이것이 Fortran 유형 파일의 기본값입니다). 예를 들어 Doxygen이 .inc 파일을 Fortran 파일로 처리하게\n"
              "하고(기본값은 PHP), .f 파일을 C로 처리하게 하려면(기본값은 Fortran), inc=Fortran f=C를 사용하세요.\n"
              "\n"
              "참고: 확장자가 없는 파일의 경우 플레이스홀더로 no_extension을 사용할 수 있습니다.\n"
              "\n"
              "사용자 정의 확장자의 경우 FILE_PATTERNS도 설정해야 합니다. 그렇지 않으면 파일이 Doxygen에서 읽히지 않습니다.\n"
              "no_extension을 지정하는 경우 FILE_PATTERNS에 *를 추가해야 합니다.\n"
              "\n"
              "기본 파일 확장자 매핑 목록도 참조하세요."
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "MARKDOWN_SUPPORT 태그가 활성화되면 Doxygen은 모든 주석을 Markdown 형식에 따라 전처리하여 더 읽기 쉬운 문서를\n"
              "가능하게 합니다. 자세한 내용은 https://daringfireball.net/projects/markdown/을 참조하세요.\n"
              "Markdown 처리의 출력은 Doxygen에 의해 추가로 처리되므로 Markdown 형식과 Doxygen, HTML 및 XML 명령을\n"
              "혼합할 수 있습니다. 하위 호환성 문제가 있는 경우에만 비활성화하세요.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "MARKDOWN_STRICT",
              "MARKDOWN_STRICT 태그가 활성화되면 Doxygen은 Doxygen의 네이티브 마크업 형식이 Markdown과 충돌하더라도 주석\n"
              "내의 텍스트를 Markdown 형식으로 처리합니다. 이는 백틱이 사용되는 경우에만 관련이 있습니다. Doxygen의 네이티브 마크업\n"
              "스타일에서는 백틱으로 시작하는 텍스트 조각을 종료하는 데 단일 따옴표를 사용할 수 있으며, 이를 인용된 텍스트로 처리하지만,\n"
              "Markdown에서는 이러한 텍스트 조각이 축어적으로 처리되며 두 번째 일치하는 백틱이 발견된 경우에만 종료됩니다. 또한 Doxygen의\n"
              "네이티브 마크업 형식에서는 백틱 섹션에 나타나는 큰따옴표를 이스케이프해야 하지만 Markdown에서는 필요하지 않습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 MARKDOWN_SUPPORT을 YES로 설정해야 합니다."
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "TOC_INCLUDE_HEADINGS 태그가 0이 아닌 값으로 설정되면 id 속성이 없는 경우에도 해당 레벨까지의 모든 제목이 목차에\n"
              "자동으로 포함됩니다.\n"
              "참고: 이 기능은 현재 Markdown 제목에만 적용됩니다.\n"
              "최소값: 0, 최대값: 99, 기본값: 6.\n"
              "이 태그는 태그 MARKDOWN_SUPPORT을 YES로 설정해야 합니다."
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "MARKDOWN_ID_STYLE 태그를 사용하여 Markdown 제목의 식별자를 생성하는 데 사용되는 알고리즘을 지정할 수 있습니다.\n"
              "참고: 각 식별자는 고유합니다.\n"
              "가능한 값:DOXYGEN 0부터 시작하는 시퀀스 번호가 뒤따르는 고정된 'autotoc_md' 문자열 사용그리고GITHUB 제목의 소문자\n"
              "버전을 사용하며 모든 공백은 '-'로 대체하고 문장 부호 문자는 제거.\n"
              "기본값은 DOXYGEN입니다.\n"
              "이 태그는 태그 MARKDOWN_SUPPORT을 YES로 설정해야 합니다."
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "활성화되면 Doxygen은 문서화된 클래스 또는 네임스페이스에 해당하는 단어를 해당 문서에 연결하려고 시도합니다. 이러한 링크는 단어 앞에\n"
              "% 기호를 배치하거나 AUTOLINK_SUPPORT 를 NO 로 설정하여 개별 경우에 방지할 수 있습니다.\n"
              "AUTOLINK_IGNORE_WORDS 태그에 나열된 단어는 자동 링크에서 제외됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "이 태그는 문서의 단어 시작과 일치하는 경우 AUTOLINK_SUPPORT를 통한 자동 링크 생성이 활성화된 경우 자동 링크 생성을 억제하는\n"
              "단어 목록을 지정합니다. 이 목록은 # 또는 \\link 또는 \\ref 명령을 사용하여 명시적으로 생성된 링크에는 영향을 주지 않습니다.\n"
              "이 태그는 태그 AUTOLINK_SUPPORT을 YES로 설정해야 합니다."
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "STL 클래스(std::string, std::vector 등)를 사용하지만 STL 소스의 (태그파일)을 입력으로 포함하지 않으려면 이\n"
              "태그를 YES 로 설정하여 Doxygen이 인수에 STL 클래스를 포함하는 함수 선언과 정의를 일치시킬 수 있도록 해야 합니다(예:\n"
              "func(std::string);와 func(std::string) {}). 이렇게 하면 STL 클래스를 포함하는 상속 다이어그램과 협업\n"
              "다이어그램도 더 완전하고 정확해집니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "Microsoft의 C++/CLI 언어를 사용하는 경우 구문 분석 지원을 활성화하기 위해 이 옵션을 YES 로 설정해야 합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SIP_SUPPORT",
              "SIP_SUPPORT 태그를 YES 로 설정하면 프로젝트가 sip (see:\n"
              "https://www.riverbankcomputing.com/software) 소스로만 구성된 경우 Doxygen은 이를 일반 C++처럼\n"
              "구문 분석하지만, 명시적인 보호 키워드가 없는 경우 모든 클래스가 private 상속이 아닌 public 상속을 사용한다고 가정합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "Microsoft의 IDL에는 속성의 getter 및 setter 메서드를 나타내는 propget 및 propput 속성이 있습니다. 이\n"
              "옵션을 YES 로 설정하면 Doxygen은 문서의 get 및 set 메서드를 속성으로 대체합니다. 이는 메서드가 실제로 단순 유형을\n"
              "가져오거나 설정하는 경우에만 작동합니다. 그렇지 않거나 메서드를 표시하려면 이 옵션을 NO 로 설정해야 합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "문서에서 멤버 그룹화가 사용되고 DISTRIBUTE_GROUP_DOC 태그가 YES 로 설정되면 Doxygen은 그룹의 첫 번째 멤버의\n"
              "문서(있는 경우)를 그룹의 다른 멤버에 재사용합니다. 기본적으로 그룹의 모든 멤버를 명시적으로 문서화해야 합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "구조체 또는 클래스를 그룹에 추가하고 이 옵션이 활성화된 경우 중첩된 클래스 또는 구조체도 동일한 그룹에 추가됩니다. 기본적으로 이 옵션은\n"
              "비활성화되어 있으며 \\ingroup를 통해 중첩된 컴파운드를 명시적으로 추가해야 합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SUBGROUPING",
              "SUBGROUPING 태그를 YES 로 설정하면 동일한 유형의 클래스 멤버 그룹(예: public 함수 그룹)을 해당 유형의 하위 그룹으로\n"
              "배치할 수 있습니다(예: public 함수 섹션 아래). 하위 그룹화를 방지하려면 NO 로 설정합니다. 또는 \\nosubgrouping\n"
              "명령을 사용하여 클래스별로 수행할 수도 있습니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "INLINE_GROUPED_CLASSES 태그가 YES 로 설정되면 클래스, 구조체 및 공용체가 포함된 그룹 내에 표시됩니다(예:\n"
              "\\ingroup 사용). 별도의 페이지(HTML 및 Man 페이지의 경우) 또는 섹션(LaTeX 및 RTF의 경우) 대신.\n"
              "\n"
              "이 기능은 SEPARATE_MEMBER_PAGES와 함께 작동하지 않습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "INLINE_SIMPLE_STRUCTS 태그가 YES 로 설정되면 공용 데이터 필드 또는 단순 typedef 필드만 있는 구조체, 클래스\n"
              "및 공용체는 정의된 범위가 문서화된 경우 해당 범위의 문서 내에 인라인으로 표시됩니다(즉, 파일, 네임스페이스 또는 그룹의 문서). NO 로\n"
              "설정되면 구조체, 클래스 및 공용체는 별도의 페이지(HTML 및 Man 페이지의 경우) 또는 섹션(LaTeX 및 RTF의 경우)에\n"
              "표시됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "TYPEDEF_HIDES_STRUCT 태그가 활성화되면 구조체, 공용체 또는 열거형의 typedef는 typedef의 이름을 가진 구조체,\n"
              "공용체 또는 열거형으로 문서화됩니다. 따라서 typedef struct TypeS {} TypeT는 문서에서 TypeT 라는 이름의 구조체로\n"
              "나타납니다. 비활성화된 경우 typedef는 파일, 네임스페이스 또는 클래스의 멤버로 표시됩니다. 구조체는 TypeS 라는 이름이 됩니다.\n"
              "이는 코딩 규칙이 모든 복합 유형을 typedef하고 typedef만 참조되며 태그 이름은 참조되지 않는 C 코드에서 일반적으로 편리합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "기호 조회 캐시의 크기는 LOOKUP_CACHE_SIZE 를 사용하여 설정할 수 있습니다. 이 캐시는 이름과 범위를 기반으로 기호를 해결하는\n"
              "데 사용됩니다. 이는 비용이 많이 드는 프로세스이며 동일한 기호가 코드에서 여러 번 나타나는 경우가 많으므로 Doxygen은 미리 해결된\n"
              "기호의 캐시를 유지합니다. 캐시가 너무 작으면 Doxygen이 느려집니다. 캐시가 너무 크면 메모리가 낭비됩니다. 캐시 크기는 다음 공식으로\n"
              "제공됩니다: 2^(16+LOOKUP_CACHE_SIZE). 유효한 범위는 0..9이며, 기본값은 0이며, 캐시 크기는 2^16=65536\n"
              "기호에 해당합니다. 실행 종료 시 Doxygen은 캐시 사용량을 보고하고 속도 관점에서 최적의 캐시 크기를 제안합니다.\n"
              "최소값: 0, 최대값: 9, 기본값: 0."
          );
  doc->add(
              "NUM_PROC_THREADS",
              "NUM_PROC_THREADS 는 처리 중에 Doxygen이 사용을 허용하는 스레드 수를 지정합니다. 0 으로 설정하면 Doxygen은\n"
              "시스템에서 사용 가능한 코어 수에 따라 설정합니다. CPU 부하와 처리 속도의 균형을 더 제어하기 위해 0보다 큰 값으로 명시적으로 설정할\n"
              "수 있습니다. 현재 입력 처리만 여러 스레드를 사용하여 수행할 수 있습니다. 이것은 아직 실험적인 기능이므로 기본값은 1로 설정되어 있으며\n"
              "병렬 처리는 효과적으로 비활성화되어 있습니다. 문제가 발생하면 보고해 주세요. dot 그래프의 병렬 생성은 DOT_NUM_THREADS\n"
              "설정에 의해 제어됩니다.\n"
              "최소값: 0, 최대값: 512, 기본값: 1."
          );
  doc->add(
              "TIMESTAMP",
              "TIMESTAMP 태그가 NO 이외의 값으로 설정되면 생성된 각 페이지에는 페이지가 생성된 날짜 또는 날짜/시간이 포함됩니다. 이를 NO\n"
              "로 설정하면 여러 실행의 출력을 비교할 때 유용합니다.\n"
              "가능한 값:YES, NO, DATETIME그리고DATE.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_ALL",
              "EXTRACT_ALL 태그가 YES 로 설정되면 Doxygen은 문서의 모든 엔티티가 문서화된 것으로 가정합니다. 문서를 사용할 수 없는\n"
              "경우에도 마찬가지입니다. private 클래스 멤버와 static 파일 멤버는 EXTRACT_PRIVATE 및 EXTRACT_STATIC\n"
              "태그가 YES 로 설정되지 않은 한 숨겨집니다.\n"
              "참고: 이렇게 하면 WARNINGS가 YES 로 설정된 경우 일반적으로 생성되는 문서화되지 않은 멤버에 대한 경고도 비활성화됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "EXTRACT_PRIVATE 태그가 YES 로 설정되면 클래스의 모든 private 멤버가 문서에 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "EXTRACT_PRIV_VIRTUAL 태그가 YES 로 설정되면 클래스의 문서화된 private 가상 메서드가 문서에 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "EXTRACT_PACKAGE 태그가 YES 로 설정되면 패키지 또는 internal 범위를 가진 모든 멤버가 문서에 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_STATIC",
              "EXTRACT_STATIC 태그가 YES 로 설정되면 파일의 모든 static 멤버가 문서에 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "EXTRACT_LOCAL_CLASSES 태그가 YES 로 설정되면 소스 파일에서 로컬로 정의된 클래스(및 구조체)가 문서에 포함됩니다.\n"
              "NO 로 설정되면 헤더 파일에서 정의된 클래스만 포함됩니다. Java 소스에는 효과가 없습니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "이 플래그는 Objective-C 코드에만 유용합니다. YES 로 설정되면 인터페이스가 아닌 구현 섹션에서 정의된 로컬 메서드가 문서에\n"
              "포함됩니다. NO 로 설정되면 인터페이스의 메서드만 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "이 플래그가 YES 로 설정되면 익명 네임스페이스의 멤버가 추출되어 문서에서 'anonymous_namespace{file}'이라는\n"
              "네임스페이스로 표시됩니다. file은 익명 네임스페이스를 포함하는 파일의 기본 이름으로 대체됩니다. 기본적으로 익명 네임스페이스는\n"
              "숨겨집니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "이 플래그가 YES 로 설정되면 선언에서 이름 없는 매개변수의 이름은 해당 정의에 의해 결정됩니다. 기본적으로 이름 없는 매개변수는 출력에서\n"
              "이름 없는 상태로 유지됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "HIDE_UNDOC_MEMBERS 태그가 YES 로 설정되면 Doxygen은 문서화된 클래스 또는 파일의 문서화되지 않은 모든 멤버를\n"
              "숨깁니다. NO 로 설정되면 이러한 멤버는 다양한 개요에 포함되지만 문서 섹션은 생성되지 않습니다. 이 옵션은 EXTRACT_ALL이\n"
              "활성화된 경우 효과가 없습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "HIDE_UNDOC_CLASSES 태그가 YES 로 설정되면 Doxygen은 클래스 계층 구조에서 일반적으로 표시되는 문서화되지 않은 모든\n"
              "클래스를 숨깁니다. NO 로 설정되면 이러한 클래스는 다양한 개요에 포함됩니다. 이 옵션은 활성화된 경우 문서화되지 않은 C++ 컨셉도\n"
              "숨깁니다. 이 옵션은 EXTRACT_ALL이 활성화된 경우 효과가 없습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "HIDE_UNDOC_NAMESPACES 태그가 YES 로 설정되면 Doxygen은 네임스페이스 계층 구조에서 일반적으로 표시되는 문서화되지\n"
              "않은 모든 네임스페이스를 숨깁니다. NO 로 설정되면 이러한 네임스페이스는 다양한 개요에 포함됩니다. 이 옵션은 EXTRACT_ALL이\n"
              "활성화된 경우 효과가 없습니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "HIDE_FRIEND_COMPOUNDS 태그가 YES 로 설정되면 Doxygen은 모든 friend 선언을 숨깁니다. NO 로 설정되면\n"
              "이러한 선언은 문서에 포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "HIDE_IN_BODY_DOCS 태그가 YES 로 설정되면 Doxygen은 함수 본문 내에서 발견된 모든 문서 블록을 숨깁니다. NO 로\n"
              "설정되면 이러한 블록은 함수의 상세 문서 블록에 추가됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "INTERNAL_DOCS",
              "INTERNAL_DOCS 태그는 \\internal 명령 뒤에 입력된 문서가 포함되는지 여부를 결정합니다. 태그가 NO 로 설정되면 문서는\n"
              "제외됩니다. 내부 문서를 포함하려면 YES 로 설정하세요.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "CASE_SENSE_NAMES 옵션의 올바른 설정을 통해 Doxygen은 기본 파일 시스템의 기능과 더 잘 일치할 수 있습니다. 파일\n"
              "시스템이 대소문자를 구분하는 경우(즉, 대소문자만 다른 이름을 가진 파일을 동일한 디렉터리에서 지원하는 경우), 입력에 그러한 파일이\n"
              "나타나는 경우 옵션을 YES 로 설정하여 해당 파일을 적절하게 처리해야 합니다. 대소문자를 구분하지 않는 파일 시스템의 경우, 옵션을 NO\n"
              "로 설정하여 대소문자만 다른 기호에 대해 작성된 출력 파일을 적절하게 처리해야 합니다. 예를 들어, CLASS 와 Class 라는 이름의 두\n"
              "클래스, 그리고 파일에 대한 참조도 정확히 일치하는 대소문자를 지정하지 않고 지원하기 위해서입니다. Windows(Cygwin 포함) 및\n"
              "macOS에서는 사용자가 일반적으로 이 옵션을 NO 로 설정해야 하지만, Linux 또는 기타 Unix 계열에서는 일반적으로 YES 로\n"
              "설정해야 합니다.\n"
              "가능한 값:SYSTEM, NO그리고YES.\n"
              "기본값은 SYSTEM입니다."
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "HIDE_SCOPE_NAMES 태그가 NO 로 설정되면 Doxygen은 문서에서 완전한 클래스 및 네임스페이스 범위를 가진 멤버를\n"
              "표시합니다. YES 로 설정되면 범위가 숨겨집니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "HIDE_COMPOUND_REFERENCE 태그가 NO(기본값)로 설정되면 Doxygen은 페이지 제목에 클래스 참조와 같은 추가 텍스트를\n"
              "추가합니다. YES 로 설정되면 컴파운드 참조가 숨겨집니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SHOW_HEADERFILE",
              "SHOW_HEADERFILE 태그가 YES 로 설정되면 클래스의 문서에는 클래스를 사용하기 위해 포함해야 하는 파일이 표시됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "SHOW_INCLUDE_FILES 태그가 YES 로 설정되면 Doxygen은 해당 파일의 문서에 파일에 의해 포함되는 파일 목록을\n"
              "배치합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "SHOW_GROUPED_MEMB_INC 태그가 YES 로 설정되면 Doxygen은 그룹화된 각 멤버의 문서에 include 문을 추가하여\n"
              "멤버를 사용하기 위해 어떤 파일을 포함해야 하는지 독자에게 알립니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "FORCE_LOCAL_INCLUDES 태그가 YES 로 설정되면 Doxygen은 문서의 include 파일을 꺾쇠 괄호 대신 큰따옴표로\n"
              "나열합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "INLINE_INFO",
              "INLINE_INFO 태그가 YES 로 설정되면 인라인 멤버의 문서에 [inline] 태그가 삽입됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "SORT_MEMBER_DOCS 태그가 YES 로 설정되면 Doxygen은 파일 및 클래스 멤버의 (상세) 문서를 멤버 이름으로 알파벳순으로\n"
              "정렬합니다. NO 로 설정되면 멤버는 선언 순서대로 표시됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "SORT_BRIEF_DOCS 태그가 YES 로 설정되면 Doxygen은 파일, 네임스페이스 및 클래스 멤버의 간결한 설명을 멤버 이름으로\n"
              "알파벳순으로 정렬합니다. NO 로 설정되면 멤버는 선언 순서대로 표시됩니다. 이는 클래스 목록 내의 클래스 순서에도 영향을 미칩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "SORT_MEMBERS_CTORS_1ST 태그가 YES 로 설정되면 Doxygen은 클래스 멤버의 (간결 및 상세) 문서를 정렬하여\n"
              "생성자와 소멸자가 먼저 나열되도록 합니다. NO 로 설정되면 생성자는 SORT_BRIEF_DOCS 및 SORT_MEMBER_DOCS에서\n"
              "정의된 각각의 순서로 표시됩니다.\n"
              "참고: SORT_BRIEF_DOCS가 NO 로 설정되면 이 옵션은 간결한 멤버 문서 정렬에 무시됩니다.\n"
              "참고: SORT_MEMBER_DOCS가 NO 로 설정되면 이 옵션은 상세한 멤버 문서 정렬에 무시됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "SORT_GROUP_NAMES 태그가 YES 로 설정되면 Doxygen은 그룹 이름의 계층 구조를 알파벳순으로 정렬합니다. NO 로\n"
              "설정되면 그룹 이름은 정의된 순서대로 표시됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "SORT_BY_SCOPE_NAME 태그가 YES 로 설정되면 클래스 목록은 네임스페이스를 포함한 완전히 정규화된 이름으로 정렬됩니다. NO\n"
              "로 설정되면 클래스 목록은 네임스페이스 부분을 포함하지 않고 클래스 이름만으로 정렬됩니다.\n"
              "참고: 이 옵션은 HIDE_SCOPE_NAMES가 YES 로 설정된 경우 그다지 유용하지 않습니다.\n"
              "참고: 이 옵션은 클래스 목록에만 적용되며 알파벳순 목록에는 적용되지 않습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "STRICT_PROTO_MATCHING 옵션이 활성화되고 Doxygen이 함수의 모든 매개변수에 대한 올바른 유형 해결에 실패한 경우,\n"
              "후보가 하나만 있거나 단순 문자열 일치로 선택할 후보가 명백한 경우에도 멤버 함수의 프로토타입과 구현 간의 일치를 거부합니다.\n"
              "STRICT_PROTO_MATCHING 을 비활성화하면 Doxygen은 그러한 경우에도 프로토타입과 구현 간의 일치를 수락합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "GENERATE_TODOLIST",
              "GENERATE_TODOLIST 태그를 사용하여 todo 목록을 활성화(YES) 또는 비활성화(NO)할 수 있습니다. 이 목록은 문서에\n"
              "\\todo 명령을 배치하여 생성됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "GENERATE_TESTLIST",
              "GENERATE_TESTLIST 태그를 사용하여 테스트 목록을 활성화(YES) 또는 비활성화(NO)할 수 있습니다. 이 목록은 문서에\n"
              "\\test 명령을 배치하여 생성됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "GENERATE_BUGLIST",
              "GENERATE_BUGLIST 태그를 사용하여 버그 목록을 활성화(YES) 또는 비활성화(NO)할 수 있습니다. 이 목록은 문서에 \\bug\n"
              "명령을 배치하여 생성됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "GENERATE_DEPRECATEDLIST 태그를 사용하여 사용되지 않는 목록을 활성화(YES) 또는 비활성화(NO)할 수 있습니다. 이\n"
              "목록은 문서에 \\deprecated 명령을 배치하여 생성됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "GENERATE_REQUIREMENTS 태그를 사용하여 요구 사항 페이지를 활성화(YES) 또는 비활성화(NO)할 수 있습니다. 활성화된\n"
              "경우 이 페이지는 입력에 \\requirement 명령을 포함하는 하나 이상의 주석 블록이 나타나면 자동으로 생성됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "REQ_TRACEABILITY_INFO 태그는 요구 사항 페이지에 추적 가능성 정보가 표시되는지 여부를 제어합니다(\\requirement\n"
              "주석 블록을 사용하는 경우에만 관련). NO 로 설정하면 추적 가능성 정보가 완전히 비활성화됩니다. UNSATISFIED_ONLY 로\n"
              "설정하면 충족 관계가 누락된 요구 사항 목록이 표시됩니다(\\satisfies 명령을 통해). 마찬가지로, UNVERIFIED_ONLY 로\n"
              "설정하면 검증 관계가 누락된 요구 사항 목록이 표시됩니다(\\verifies 명령을 통해). 태그를 YES(기본값)로 설정하면 해당되는 경우\n"
              "두 목록이 모두 표시됩니다.\n"
              "가능한 값:YES, NO, UNSATISFIED_ONLY그리고UNVERIFIED_ONLY.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_REQUIREMENTS을 YES로 설정해야 합니다."
          );
  doc->add(
              "ENABLED_SECTIONS",
              "ENABLED_SECTIONS 태그를 사용하여 \\if <section_label> ... \\endif 및 \\cond\n"
              "<section_label> ... \\endcond 블록으로 표시된 조건부 문서 섹션을 활성화할 수 있습니다."
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "MAX_INITIALIZER_LINES 태그는 변수 또는 매크로/정의의 초기 값이 문서에 표시되기 위해 가질 수 있는 최대 줄 수를\n"
              "결정합니다. 초기화자가 여기에 지정된 줄 수를 초과하면 숨겨집니다. 초기화자를 완전히 숨기려면 0 값을 사용합니다. 개별 변수와\n"
              "매크로/정의의 값 외관은 이 설정과 관계없이 문서에서 \\showinitializer 또는 \\hideinitializer 명령을 사용하여\n"
              "제어할 수 있습니다.\n"
              "최소값: 0, 최대값: 10000, 기본값: 30."
          );
  doc->add(
              "SHOW_USED_FILES",
              "SHOW_USED_FILES 태그를 NO 로 설정하면 클래스와 구조체의 문서 하단에 생성되는 파일 목록이 비활성화됩니다. YES 로\n"
              "설정되면 목록은 문서 생성에 사용된 파일을 나타냅니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SHOW_FILES",
              "SHOW_FILES 태그를 NO 로 설정하면 파일 페이지 생성이 비활성화됩니다. 이렇게 하면 빠른 인덱스와 폴더 트리 보기(지정된\n"
              "경우)에서 파일 항목이 제거됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SHOW_NAMESPACES",
              "SHOW_NAMESPACES 태그를 NO 로 설정하면 네임스페이스 페이지 생성이 비활성화됩니다. 이렇게 하면 빠른 인덱스와 폴더 트리\n"
              "보기(지정된 경우)에서 네임스페이스 항목이 제거됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "FILE_VERSION_FILTER 태그를 사용하여 Doxygen이 각 파일의 현재 버전을 가져오기 위해 호출하는 프로그램 또는 스크립트를\n"
              "지정할 수 있습니다(일반적으로 버전 관리 시스템에서). Doxygen은 popen()을 통해 명령command input_file을 실행하여\n"
              "프로그램을 호출합니다. 여기서 command 는 FILE_VERSION_FILTER 태그의 값, input_file 은 Doxygen이\n"
              "제공하는 입력 파일의 이름입니다. 프로그램이 표준 출력에 쓰는 모든 것은 파일 버전으로 사용됩니다.예시는 설명서를 참조하십시오."
          );
  doc->add(
              "LAYOUT_FILE",
              "LAYOUT_FILE 태그를 사용하여 Doxygen이 구문 분석할 레이아웃 파일을 지정할 수 있습니다. 레이아웃 파일은 생성된 출력 파일의\n"
              "전역 구조를 출력 형식 독립적인 방식으로 제어합니다. Doxygen의 기본값을 나타내는 레이아웃 파일을 생성하려면 -l 옵션을 지정하여\n"
              "Doxygen을 실행합니다. 선택적으로 파일 이름을 지정할 수 있습니다. 생략하면 DoxygenLayout.xml 이 레이아웃 파일의\n"
              "이름으로 사용됩니다. 자세한 내용은 섹션 \"Changing the layout of pages\" 도 참조하세요.\n"
              "\n"
              "DoxygenLayout.xml 이라는 파일을 포함하는 디렉터리에서 Doxygen을 실행하면 LAYOUT_FILE 태그가 비워 두어도\n"
              "Doxygen이 자동으로 이를 구문 분석합니다."
          );
  doc->add(
              "CITE_BIB_FILES",
              "CITE_BIB_FILES 태그를 사용하여 참조 정의를 포함하는 하나 이상의 bib 파일을 지정할 수 있습니다. 이것은 .bib 파일\n"
              "목록이어야 합니다. .bib 확장자는 생략된 경우 자동으로 추가됩니다. 이를 위해서는 bibtex 도구가 설치되어 있어야 합니다. 자세한\n"
              "내용은 https://en.wikipedia.org/wiki/BibTeX도 참조하세요. LaTeX의 경우 참고 문헌의 스타일은\n"
              "LATEX_BIB_STYLE를 사용하여 제어할 수 있습니다. 이 기능을 사용하려면 검색 경로에서 bibtex 와 perl 을 사용할 수\n"
              "있어야 합니다. 참조 생성 방법은 \\cite도 참조하세요."
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "EXTERNAL_TOOL_PATH 태그를 사용하여 latex 및 gs 와 같은 외부 도구를 찾을 수 있도록 검색 경로(PATH 환경\n"
              "변수)를 확장할 수 있습니다.\n"
              "참고: EXTERNAL_TOOL_PATH에서 지정된 디렉터리는 PATH 변수에서 이미 지정된 경로 앞에 추가되며, 지정된 순서대로\n"
              "추가됩니다.\n"
              "참고: 이 옵션은 Doxywizard에서 Doxygen을 실행하는 경우 macOS 버전 14(Sonoma) 이상에서 특히 편리합니다. 이\n"
              "경우 PATH에 대한 사용자 정의 변경 사항이 무시되기 때문입니다. macOS의 일반적인 예는\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "표준 경로와 함께 설정하면 외부 도구를 시작할 때 doxygen이 사용하는 전체 검색 경로는\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin\n"
              "이 됩니다."
          );
  doc->add(
              "QUIET",
              "QUIET 태그를 사용하여 Doxygen에 의해 표준 출력에 생성되는 메시지를 켜거나 끌 수 있습니다. QUIET 가 YES 로 설정되면\n"
              "메시지가 꺼져 있음을 의미합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "WARNINGS",
              "WARNINGS 태그를 사용하여 Doxygen에 의해 표준 오류(stderr)에 생성되는 경고 메시지를 켜거나 끌 수 있습니다.\n"
              "WARNING S가 YES 로 설정되면 경고가 켜져 있음을 의미합니다.\n"
              "\n"
              "팁: 문서 작성 중에 경고를 켜두세요.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "WARN_IF_UNDOCUMENTED 태그가 YES 로 설정되면 Doxygen은 문서화되지 않은 멤버에 대한 경고를 생성합니다.\n"
              "EXTRACT_ALL이 YES 로 설정되면 이 플래그는 자동으로 비활성화됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "WARN_IF_DOC_ERROR 태그가 YES 로 설정되면 Doxygen은 문서의 잠재적 오류(문서화된 함수에서 일부 매개변수를 두 번\n"
              "문서화, 존재하지 않는 매개변수 문서화, 마크업 명령 잘못 사용 등)에 대해 경고를 생성합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "WARN_IF_INCOMPLETE_DOC 이 YES 로 설정되면 Doxygen은 불완전한 함수 매개변수 문서에 대해 경고합니다. NO 로\n"
              "설정되면 Doxygen은 일부 매개변수에 문서가 없는 것을 경고 없이 수락합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "이 WARN_NO_PARAMDOC 옵션을 활성화하면 문서화되었지만 매개변수 또는 반환 값 문서가 없는 함수에 대한 경고를 얻을 수 있습니다.\n"
              "NO 로 설정되면 Doxygen은 매개변수 문서의 오류에 대해서만 경고하고 문서 누락에 대해서는 경고하지 않습니다. EXTRACT_ALL이\n"
              "YES 로 설정되면 이 플래그는 자동으로 비활성화됩니다. WARN_IF_INCOMPLETE_DOC도 참조하세요.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "WARN_IF_UNDOC_ENUM_VAL 옵션이 YES 로 설정되면 Doxygen은 문서화되지 않은 열거형 값에 대해 경고합니다. NO 로\n"
              "설정되면 Doxygen은 문서화되지 않은 열거형 값을 수락합니다. EXTRACT_ALL이 YES 로 설정되면 이 플래그는 자동으로\n"
              "비활성화됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "WARN_LAYOUT_FILE 옵션이 YES 로 설정되면 Doxygen은 사용자 정의 레이아웃 파일 구문 분석 중에 발견된 문제(누락 또는\n"
              "잘못된 요소 등)에 대해 경고합니다. 자세한 내용은 LAYOUT_FILE도 참조하세요. NO 로 설정되면 레이아웃 파일 문제가 억제됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "WARN_AS_ERROR",
              "WARN_AS_ERROR 태그가 YES 로 설정되면 Doxygen은 경고가 발생하자마자 중지됩니다. WARN_AS_ERROR 태그가\n"
              "FAIL_ON_WARNINGS 로 설정되면 Doxygen은 WARN_AS_ERROR 태그가 NO 로 설정된 것처럼 실행을 계속하지만,\n"
              "Doxygen 프로세스 종료 시 Doxygen은 0이 아닌 상태로 반환됩니다. WARN_AS_ERROR 태그가\n"
              "FAIL_ON_WARNINGS_PRINT 로 설정되면 Doxygen은 FAIL_ON_WARNINGS 처럼 작동하지만 WARN_LOGFILE이\n"
              "정의되지 않은 경우 Doxygen은 경고 메시지를 다른 메시지 사이에 쓰지 않고 실행 종료 시 씁니다. WARN_LOGFILE이 정의된 경우\n"
              "경고 메시지는 정의된 파일에 있는 것 외에도 실행 종료 시에도 표시됩니다. 단, WARN_LOGFILE이 -(즉, 표준 출력\n"
              "stdout)으로 정의된 경우는 제외되며, 이 경우 동작은 FAIL_ON_WARNINGS 설정과 동일하게 유지됩니다.\n"
              "가능한 값:NO, YES, FAIL_ON_WARNINGS그리고FAIL_ON_WARNINGS_PRINT.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "WARN_FORMAT",
              "WARN_FORMAT 태그는 Doxygen이 생성할 수 있는 경고 메시지의 형식을 결정합니다. 문자열에는 경고가 발생한 파일과 줄 번호,\n"
              "그리고 경고 텍스트로 대체되는 $file, $line, 및 $text 태그가 포함되어야 합니다. 선택적으로 형식에는 $version을 포함할\n"
              "수 있습니다. 이는 (FILE_VERSION_FILTER를 통해 얻을 수 있는 경우) 파일의 버전으로 대체됩니다.\n"
              "참조: WARN_LINE_FORMAT\n"
              "기본값은 $file:$line: $text입니다."
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "WARN_FORMAT 명령의 $text 부분에서 더 구체적인 위치에 대한 참조가 제공될 수 있습니다. 이 위치로 쉽게 이동할 수\n"
              "있도록(Doxygen 외부에서) 사용자는 사용자 정의 \"잘라내기\"/\"붙여넣기\" 문자열을 정의할 수 있습니다. 예:\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "참조: WARN_FORMAT\n"
              "기본값은 at line $line of file $file입니다."
          );
  doc->add(
              "WARN_LOGFILE",
              "WARN_LOGFILE 태그를 사용하여 경고 및 오류 메시지가 기록될 파일을 지정할 수 있습니다. 비워 두면 출력은 표준\n"
              "오류(stderr)에 기록됩니다. 지정된 파일이 쓰기 위해 열 수 없는 경우 경고 및 오류 메시지는 표준 오류에 기록됩니다. - 파일이\n"
              "지정된 경우 경고 및 오류 메시지는 표준 출력(stdout)에 기록됩니다."
          );
  doc->add(
              "INPUT",
              "INPUT 태그는 문서화된 소스 파일을 포함하는 파일 및/또는 디렉터리를 지정하는 데 사용됩니다. myfile.cpp 와 같은 파일 이름\n"
              "또는 /usr/src/myproject 와 같은 디렉터리를 입력할 수 있습니다. 파일 또는 디렉터리를 공백으로 구분하세요.\n"
              "FILE_PATTERNS 및 EXTENSION_MAPPING도 참조하세요.\n"
              "참고: 이 태그가 비어 있으면 현재 디렉터리가 검색됩니다."
          );
  doc->add(
              "INPUT_ENCODING",
              "이 태그를 사용하여 Doxygen이 구문 분석하는 소스 파일의 문자 인코딩을 지정할 수 있습니다. 내부적으로 Doxygen은 UTF-8\n"
              "인코딩을 사용합니다. Doxygen은 트랜스코딩을 위해 libiconv(또는 libc에 내장된 iconv)를 사용합니다. 가능한 인코딩\n"
              "목록은 libiconv 문서 (see:\n"
              "https://www.gnu.org/software/libiconv/)를 참조하세요.\n"
              "참조: INPUT_FILE_ENCODING\n"
              "기본값은 UTF-8입니다."
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "이 태그를 사용하여 Doxygen이 구문 분석하는 소스 파일의 문자 인코딩을 지정할 수 있습니다. INPUT_FILE_ENCODING 태그를\n"
              "사용하여 파일 패턴별로 문자 인코딩을 지정할 수 있습니다. Doxygen은 파일 이름을 각 패턴과 비교하고 일치하는 경우 기본\n"
              "INPUT_ENCODING 대신 인코딩을 적용합니다. 문자 인코딩은 pattern=encoding 형식의\n"
              "목록입니다(*.php=ISO-8859-1처럼).\n"
              "참조: 지원되는 인코딩에 대한 자세한 내용은 INPUT_ENCODING을 참조하세요."
          );
  doc->add(
              "FILE_PATTERNS",
              "INPUT 태그의 값에 디렉터리가 포함된 경우 FILE_PATTERNS 태그를 사용하여 디렉터리 내의 소스 파일을 필터링하는 하나 이상의\n"
              "와일드카드 패턴(*.cpp 및 *.h처럼)을 지정할 수 있습니다.\n"
              "\n"
              "사용자 정의 확장자 또는 직접 지원되지 않는 확장자의 경우 확장자에 대한 EXTENSION_MAPPING도 설정해야 합니다. 그렇지 않으면\n"
              "파일이 Doxygen에서 읽히지 않습니다.\n"
              "\n"
              "기본적으로 확인되는 파일 패턴 목록은 기본 파일 확장자 매핑 목록과 다를 수 있습니다.\n"
              "\n"
              "비워 두면 다음 패턴이 테스트됩니다:*.c, *.cc, *.cxx, *.cxxm, *.cpp, *.cppm, *.ccm, *.c++,\n"
              "*.c++m, *.java, *.ii, *.ixx, *.ipp, *.i++, *.inl, *.idl, *.ddl, *.odl, *.h,\n"
              "*.hh, *.hxx, *.hpp, *.h++, *.l, *.cs, *.d, *.php, *.php4, *.php5, *.phtml,\n"
              "*.inc, *.m, *.markdown, *.md, *.mm, *.dox (to be provided as Doxygen C\n"
              "comment), *.py, *.pyw, *.f90, *.f95, *.f03, *.f08, *.f18, *.f, *.for, *.vhd,\n"
              "*.vhdl, *.ucf, *.qsf그리고*.ice."
          );
  doc->add(
              "RECURSIVE",
              "RECURSIVE 태그를 사용하여 입력 파일의 하위 디렉터리도 검색할지 여부를 지정할 수 있습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXCLUDE",
              "EXCLUDE 태그를 사용하여 INPUT 소스 파일에서 제외할 파일 및/또는 디렉터리를 지정할 수 있습니다. 이를 통해 INPUT 태그에서\n"
              "루트가 지정된 디렉터리 트리에서 하위 디렉터리를 쉽게 제외할 수 있습니다.\n"
              "\n"
              "상대 경로는 Doxygen이 실행되는 디렉터리에서의 상대 경로입니다."
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "EXCLUDE_SYMLINKS 태그를 사용하여 심볼릭 링크(Unix 파일 시스템의 기능)인 파일 또는 디렉터리를 입력에서 제외할지 여부를\n"
              "선택할 수 있습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "INPUT 태그의 값에 디렉터리가 포함된 경우 EXCLUDE_PATTERNS 태그를 사용하여 해당 디렉터리에서 특정 파일을 제외하는 하나\n"
              "이상의 와일드카드 패턴을 지정할 수 있습니다.\n"
              "\n"
              "와일드카드는 절대 경로를 가진 파일과 일치하므로 모든 테스트 디렉터리를 제외하려면 예를 들어 패턴 */test/*를 사용하세요."
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "EXCLUDE_SYMBOLS 태그를 사용하여 출력에서 제외할 하나 이상의 기호 이름(네임스페이스, 클래스, 함수 등)을 지정할 수\n"
              "있습니다. 기호 이름은 완전히 정규화된 이름, 단어, 또는 와일드카드 *가 사용되는 경우 부분 문자열일 수 있습니다. 예:\n"
              "ANamespace, AClass, ANamespace::AClass, ANamespace::*Test"
          );
  doc->add(
              "EXAMPLE_PATH",
              "EXAMPLE_PATH 태그를 사용하여 포함될 코드 예제 조각을 포함하는 하나 이상의 파일 또는 디렉터리를 지정할 수\n"
              "있습니다(\\include 명령 참조)."
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "EXAMPLE_PATH 태그의 값에 디렉터리가 포함된 경우 EXAMPLE_PATTERNS 태그를 사용하여 디렉터리 내의 소스 파일을\n"
              "필터링하는 하나 이상의 와일드카드 패턴(*.cpp 및 *.h처럼)을 지정할 수 있습니다. 비워 두면 모든 파일이 포함됩니다."
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "EXAMPLE_RECURSIVE 태그가 YES 로 설정되면 RECURSIVE 태그의 값과 관계없이 \\include 또는\n"
              "\\dontinclude 명령에 사용할 입력 파일의 하위 디렉터리가 검색됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "IMAGE_PATH",
              "IMAGE_PATH 태그를 사용하여 문서에 포함될 이미지를 포함하는 하나 이상의 파일 또는 디렉터리를 지정할 수 있습니다(\\image 명령\n"
              "참조)."
          );
  doc->add(
              "INPUT_FILTER",
              "INPUT_FILTER 태그를 사용하여 Doxygen이 각 입력 파일을 필터링하기 위해 호출하는 프로그램을 지정할 수 있습니다.\n"
              "Doxygen은 popen()을 통해 명령:\n"
              "\n"
              "<filter> <input-file>\n"
              "\n"
              "을 실행하여 필터 프로그램을 호출합니다. 여기서 <filter>는 INPUT_FILTER 태그의 값, <input-file>은 입력 파일의\n"
              "이름입니다. Doxygen은 필터 프로그램이 표준 출력에 쓰는 출력을 사용합니다. FILTER_PATTERNS가 지정된 경우 이 태그는\n"
              "무시됩니다.\n"
              "\n"
              "필터는 줄을 추가하거나 제거해서는 안 됩니다. 코드가 스캔되기 전에 적용되지만 출력 코드가 생성될 때는 적용되지 않습니다. 줄이 추가되거나\n"
              "제거되면 앵커가 올바르게 배치되지 않습니다.\n"
              "\n"
              "Doxygen은 처리된 데이터를 표준 출력에 쓰여 추가 처리를 위해 사용하므로 디버그 문이나 사용된 명령과 같은 다른 것(Windows 배치\n"
              "파일의 경우 항상 @echo OFF 사용)은 표준 출력에 쓰여서는 안 됩니다.\n"
              "\n"
              "사용자 정의 확장자 또는 직접 지원되지 않는 확장자의 경우 확장자에 대한 EXTENSION_MAPPING도 설정해야 합니다. 그렇지 않으면\n"
              "파일이 Doxygen에서 올바르게 처리되지 않습니다.\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "FILTER_PATTERNS 태그를 사용하여 파일 패턴별로 필터를 지정할 수 있습니다. Doxygen은 파일 이름을 각 패턴과 비교하고\n"
              "일치하는 경우 필터를 적용합니다. 필터는 pattern=filter 형식의 목록입니다(*.cpp=my_cpp_filter처럼). 필터 사용\n"
              "방법은 INPUT_FILTER를 참조하세요. FILTER_PATTERNS 태그가 비어 있거나 패턴 중 어느 것도 파일 이름과 일치하지 않으면\n"
              "INPUT_FILTER가 적용됩니다.\n"
              "\n"
              "사용자 정의 확장자 또는 직접 지원되지 않는 확장자의 경우 확장자에 대한 EXTENSION_MAPPING도 설정해야 합니다. 그렇지 않으면\n"
              "파일이 Doxygen에서 올바르게 처리되지 않습니다.\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "FILTER_SOURCE_FILES 태그가 YES 로 설정되면 입력 필터(INPUT_FILTER를 사용하여 설정된 경우)는 브라우징할 소스\n"
              "파일을 생성하는 데 사용되는 입력 파일도 필터링하는 데 사용됩니다(즉, SOURCE_BROWSER가 YES 로 설정된 경우).\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "FILTER_SOURCE_PATTERNS 태그를 사용하여 파일 패턴별로 소스 필터를 지정할 수 있습니다. 패턴은 FILTER_PATTERN\n"
              "설정을 재정의하며(있는 경우), *.ext=를 사용하여 특정 패턴에 대한 소스 필터링을 비활성화할 수도 있습니다(필터에 이름을 지정하지\n"
              "않고).\n"
              "이 태그는 태그 FILTER_SOURCE_FILES을 YES로 설정해야 합니다."
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "USE_MDFILE_AS_MAINPAGE 태그가 입력의 일부인 마크다운 파일의 이름을 참조하는 경우 해당 내용은 메인\n"
              "페이지(index.html)에 배치됩니다. 이는 예를 들어 GitHub에 프로젝트가 있고 소개 페이지도 Doxygen 출력에 재사용하려는\n"
              "경우에 편리합니다."
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "IMPLICIT_DIR_DOCS 태그가 YES 로 설정되면 프로젝트 루트의 하위 디렉터리에서 발견된 README.md 파일은\n"
              "README.md가 \\dir, \\page, 또는 \\mainpage 명령으로 시작하지 않는 한 해당 하위 디렉터리의 문서로 사용됩니다. NO\n"
              "로 설정되면 README.md 파일이 디렉터리 문서로 사용되기 위해서는 명시적인 \\dir 명령으로 시작해야 합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "Fortran 표준은 고정 형식 Fortran 코드에서 위치 72 이후의 모든 문자가 주석으로 간주되도록 규정합니다. 일반적인 확장은 자동\n"
              "주석이 시작되기 전에 더 긴 줄을 허용하는 것입니다. FORTRAN_COMMENT_AFTER 설정을 통해 자동 주석이 시작되기 전에 더 긴\n"
              "줄을 처리할 수 있습니다.\n"
              "최소값: 7, 최대값: 10000, 기본값: 72."
          );
  doc->add(
              "SOURCE_BROWSER",
              "SOURCE_BROWSER 태그가 YES 로 설정되면 소스 파일 목록이 생성됩니다. 문서화된 엔티티는 이러한 소스와 상호 참조됩니다.\n"
              "\n"
              "참고: 생성된 출력에서 모든 소스 코드를 제거하려면 VERBATIM_HEADERS도 NO 로 설정되어 있는지 확인하세요.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "INLINE_SOURCES",
              "INLINE_SOURCES 태그를 YES 로 설정하면 함수, 여러 줄 매크로, 열거형 또는 목록 초기화 변수의 본문이 문서에 직접\n"
              "포함됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "STRIP_CODE_COMMENTS 태그를 YES 로 설정하면 Doxygen은 생성된 소스 코드 조각에서 특수 주석 블록을 숨기도록\n"
              "지시합니다. 일반 C, C++, Fortran 주석은 항상 표시된 상태로 유지됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "REFERENCED_BY_RELATION 태그가 YES 로 설정되면 문서화된 각 엔티티에 대해 이를 참조하는 모든 문서화된 함수가\n"
              "나열됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "REFERENCES_RELATION",
              "REFERENCES_RELATION 태그가 YES 로 설정되면 문서화된 각 함수에 대해 해당 함수에 의해 호출/사용되는 모든 문서화된\n"
              "엔티티가 나열됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "REFERENCES_LINK_SOURCE 태그가 YES 로 설정되고 SOURCE_BROWSER 태그가 YES 로 설정되면\n"
              "REFERENCES_RELATION 및 REFERENCED_BY_RELATION 목록의 함수에서 하이퍼링크는 소스 코드에 연결됩니다. 그렇지\n"
              "않으면 문서에 연결됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "SOURCE_TOOLTIPS 가 활성화된 경우(기본값) 소스 코드의 하이퍼링크 위에 마우스를 올리면 프로토타입, 간결한 설명, 정의 및\n"
              "문서에 대한 링크와 같은 추가 정보가 포함된 툴팁이 표시됩니다. 이로 인해 HTML 파일이 커지고 큰 파일의 로딩이 약간 느려질 수 있으므로\n"
              "이 기능을 비활성화할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 SOURCE_BROWSER을 YES로 설정해야 합니다."
          );
  doc->add(
              "USE_HTAGS",
              "USE_HTAGS 태그가 YES 로 설정되면 소스 코드에 대한 참조는 Doxygen의 기본 제공 소스 브라우저 대신 htags(1) 도구에\n"
              "의해 생성된 HTML을 가리킵니다. htags 도구는 GNU의 글로벌 소스 태깅 시스템의\n"
              "일부입니다(https://www.gnu.org/software/global/global.html 참조). 버전 4.8.6 이상이 필요합니다.\n"
              "\n"
              "사용하려면 다음 단계를 수행하세요:\n"
              "- global 의 최신 버전을 설치하세요\n"
              "- 설정 파일에서 SOURCE_BROWSER와 USE_HTAGS 를 활성화하세요\n"
              "- INPUT이 소스 트리의 루트를 가리키는지 확인하세요\n"
              "- 평소처럼 doxygen 을 실행하세요\n"
              "\n"
              "Doxygen은 htags 를 호출하며(이는 다시 gtags 를 호출함), 이러한 도구는 명령줄에서(즉, 검색 경로에서) 사용할 수 있어야\n"
              "합니다.\n"
              "\n"
              "결과: Doxygen에 의해 생성된 소스 브라우저 대신 소스 코드에 대한 링크는 htags 의 출력을 가리킵니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 SOURCE_BROWSER을 YES로 설정해야 합니다."
          );
  doc->add(
              "VERBATIM_HEADERS",
              "VERBATIM_HEADERS 태그가 YES 로 설정되면 Doxygen은 include가 지정된 각 클래스의 헤더 파일의 축어적 복사본을\n"
              "생성합니다. 이를 비활성화하려면 NO 로 설정하세요.\n"
              "참조: 섹션 \\class.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "CLANG_ASSISTED_PARSING 태그가 YES 로 설정되면 Doxygen은 clang 파서 (see:\n"
              "http://clang.llvm.org/)를 사용하여 성능 저하를 대가로 더 정확한 구문 분석을 수행합니다. 이는 Doxygen의 기본 제공\n"
              "파서가 필요한 유형 정보가 부족한 템플릿이 풍부한 C++ 코드에서 특히 유용합니다.\n"
              "참고: 이 옵션의 가용성은 Doxygen이 CMake의 -Duse_libclang=ON 옵션으로 생성되었는지 여부에 따라 달라집니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "CLANG_ASSISTED_PARSING 태그가 YES 로 설정되고 CLANG_ADD_INC_PATHS 태그가 YES 로 설정되면\n"
              "Doxygen은 각 입력의 디렉터리를 include 경로에 추가합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 CLANG_ASSISTED_PARSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "CLANG_OPTIONS",
              "clang 지원 구문 분석이 활성화된 경우 컴파일러를 호출할 때 일반적으로 사용하는 명령줄 옵션을 컴파일러에 제공할 수 있습니다.\n"
              "include 경로는 INPUT 및 INCLUDE_PATH에서 지정된 파일 및 디렉터리에 대해 Doxygen에 의해 이미 설정되어 있습니다.\n"
              "이 태그는 태그 CLANG_ASSISTED_PARSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "clang 지원 구문 분석이 활성화된 경우 compile_commands.json이라는 파일을 포함하는 디렉터리의 경로를 clang 파서에\n"
              "제공할 수 있습니다. 이 파일은 소스 파일이 빌드될 때 사용된 옵션을 포함하는 컴파일 데이터베이스 (see:\n"
              "http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html)입니다. 이는 clang-check와\n"
              "같은 clang 도구에 -p 옵션을 지정하는 것과 동일합니다. 이러한 옵션은 파서에 전달됩니다. CLANG_OPTIONS에서 지정된 옵션도\n"
              "추가됩니다.\n"
              "참고: 이 옵션의 가용성은 Doxygen이 CMake의 -Duse_libclang=ON 옵션으로 생성되었는지 여부에 따라 달라집니다."
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "ALPHABETICAL_INDEX 태그가 YES 로 설정되면 모든 컴파운드의 알파벳순 인덱스가 생성됩니다. 프로젝트에 많은 수의 클래스,\n"
              "구조체, 공용체 또는 인터페이스가 포함된 경우 이를 활성화하세요.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "IGNORE_PREFIX",
              "IGNORE_PREFIX 태그를 사용하여 인덱스 헤더 생성 중에 무시되는 접두사(또는 접두사 목록)를 지정할 수 있습니다.\n"
              "IGNORE_PREFIX 태그는 클래스, 함수 및 멤버 이름에 대해 작동합니다. 엔티티는 접두사를 제거한 후 남은 엔티티 이름의 첫 번째\n"
              "문자 아래에 알파벳순 목록에 배치됩니다.\n"
              "이 태그는 태그 ALPHABETICAL_INDEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_HTML",
              "GENERATE_HTML 태그가 YES 로 설정되면 Doxygen은 HTML 출력을 생성합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "HTML_OUTPUT",
              "HTML_OUTPUT 태그는 HTML 문서가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면 OUTPUT_DIRECTORY의\n"
              "값이 그 앞에 배치됩니다.\n"
              "기본 디렉토리는 html입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "HTML_FILE_EXTENSION 태그를 사용하여 생성되는 각 HTML 페이지의 파일 확장자를 지정할 수 있습니다(예: .htm,\n"
              ".php, .asp).\n"
              "기본값은 .html입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_HEADER",
              "HTML_HEADER 태그를 사용하여 생성되는 각 HTML 페이지의 사용자 정의 HTML 헤더 파일을 지정할 수 있습니다. 태그가 비워\n"
              "두면 Doxygen은 표준 헤더를 생성합니다.\n"
              "\n"
              "유효한 HTML을 얻으려면 헤더 파일에 Doxygen이 필요로 하는 모든 스크립트와 스타일시트를 포함해야 합니다. 이는 사용되는 설정 옵션에\n"
              "따라 다릅니다(예: GENERATE_TREEVIEW 설정). 다음을 사용하여 기본 헤더에서 시작하는 것이 좋습니다:\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "그런 다음 파일 new_header.html 을 수정하세요. Doxygen이 일반적으로 사용하는 기본 헤더 생성 방법에 대해서는 섹션\n"
              "\"Doxygen usage\" 도 참조하세요.\n"
              "참고: 헤더는 변경될 수 있으므로 일반적으로 Doxygen의 새 버전으로 업그레이드할 때 기본 헤더를 다시 생성해야 합니다.사용 가능한 마커\n"
              "및 블록 이름에 대한 설명은 설명서를 참조하십시오.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_FOOTER",
              "HTML_FOOTER 태그를 사용하여 생성되는 각 HTML 페이지의 사용자 정의 HTML 푸터를 지정할 수 있습니다. 태그가 비워 두면\n"
              "Doxygen은 표준 푸터를 생성합니다. 기본 푸터 생성 방법과 푸터 내에서 사용할 수 있는 특수 명령에 대한 자세한 내용은\n"
              "HTML_HEADER를 참조하세요. Doxygen이 일반적으로 사용하는 기본 푸터 생성 방법에 대해서는 섹션 \"Doxygen usage\" 도\n"
              "참조하세요.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_STYLESHEET",
              "HTML_STYLESHEET 태그를 사용하여 각 HTML 페이지에서 사용되는 사용자 정의 계단식 스타일시트를 지정할 수 있습니다. HTML\n"
              "출력의 외관을 미세 조정하는 데 사용할 수 있습니다. 비워 두면 Doxygen은 기본 스타일시트를 생성합니다. Doxygen이 일반적으로\n"
              "사용하는 스타일시트 생성 방법에 대해서는 섹션 \"Doxygen usage\" 도 참조하세요.\n"
              "참고: 더 견고하므로 이 태그 대신 HTML_EXTRA_STYLESHEET를 사용하는 것이 좋습니다. 이\n"
              "태그(HTML_STYLESHEET)는 향후 폐기될 예정입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "HTML_EXTRA_STYLESHEET 태그를 사용하여 Doxygen에 의해 생성된 표준 스타일시트 이후에 포함되는 추가 사용자 정의\n"
              "계단식 스타일시트를 지정할 수 있습니다. 이 옵션을 사용하면 특정 스타일 측면을 재정의할 수 있습니다. 이는 표준 스타일시트를 대체하지\n"
              "않으므로 향후 업데이트에 대해 더 견고한 HTML_STYLESHEET를 사용하는 것보다 권장됩니다. Doxygen은 스타일시트 파일을 출력\n"
              "디렉터리에 복사합니다.\n"
              "참고: 추가 스타일시트 파일의 순서는 중요합니다(예: 목록의 마지막 스타일시트는 목록에서 이전 것의 설정을 재정의함).\n"
              "참고: 스크롤바 스타일링은 현재 Webkit/Chromium에서 재정의할 수 없으므로 하나 이상의 추가 스타일시트가 지정된 경우 스타일링은\n"
              "기본 doxygen.css에서 제외됩니다. 따라서 스크롤바 사용자 정의가 필요한 경우 명시적으로 추가해야 합니다.예시는 설명서를\n"
              "참조하십시오.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "HTML_EXTRA_FILES 태그를 사용하여 HTML 출력 디렉터리에 복사될 하나 이상의 추가 이미지 또는 다른 소스 파일을 지정할 수\n"
              "있습니다. 이러한 파일은 기본 HTML 출력 디렉터리에 복사됩니다. HTML_HEADER 및/또는 HTML_FOOTER 파일에서\n"
              "$relpath^ 마커를 사용하여 이러한 파일을 로드합니다. HTML_STYLESHEET 파일에서는 파일 이름만 사용합니다. 또한 파일은\n"
              "있는 그대로 복사된다는 점에도 유의하세요. 사용 가능한 명령이나 마커가 없습니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_COLORSTYLE",
              "HTML_COLORSTYLE 태그를 사용하여 생성된 HTML 출력이 어두운 테마 또는 밝은 테마로 렌더링되는지 여부를 지정할 수 있습니다.\n"
              "가능한 값:LIGHT 항상 라이트 모드 출력 생성, DARK 항상 다크 모드 출력 생성, AUTO_LIGHT 사용자 기본 설정에 따라 모드를\n"
              "자동으로 설정, 기본 설정이 없으면 라이트 모드 사용(기본값), AUTO_DARK 사용자 기본 설정에 따라 모드를 자동으로 설정, 기본\n"
              "설정이 없으면 다크 모드 사용그리고TOGGLE 버튼을 통해 라이트 모드와 다크 모드 간 전환 허용.\n"
              "기본값은 AUTO_LIGHT입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "HTML_COLORSTYLE_HUE 태그는 HTML 출력의 색상을 제어합니다. Doxygen은 이 색상에 따라 스타일시트와 배경 이미지의\n"
              "색상을 조정합니다. 색조는 색상 환에서 각도로 지정됩니다. 자세한 내용은 https://en.wikipedia.org/wiki/Hue를\n"
              "참조하세요. 예를 들어, 값 0은 빨강, 60은 노랑, 120은 녹색, 180은 청록, 240은 파랑, 300은 보라, 360은 다시 빨강을\n"
              "나타냅니다.\n"
              "최소값: 0, 최대값: 359, 기본값: 220.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "HTML_COLORSTYLE_SAT 태그는 HTML 출력의 색상 순도(또는 채도)를 제어합니다. 값이 0이면 출력은 회색조만 사용합니다.\n"
              "값이 255이면 가장 선명한 색상이 생성됩니다.\n"
              "최소값: 0, 최대값: 255, 기본값: 100.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "HTML_COLORSTYLE_GAMMA 태그는 HTML 출력의 색상 휘도 성분에 적용되는 감마 보정을 제어합니다. 100 미만의 값은\n"
              "출력을 점차 밝게 하고, 100을 초과하는 값은 출력을 어둡게 합니다. 값을 100으로 나눈 것이 실제로 적용되는 감마입니다. 따라서 80은\n"
              "감마 0.8을 나타내고, 값 220은 감마 2.2를 나타내며, 100은 감마를 변경하지 않습니다.\n"
              "최소값: 40, 최대값: 240, 기본값: 80.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "HTML_DYNAMIC_MENUS 태그가 YES 로 설정되면 생성된 HTML 문서에는 JavaScript를 통해 동적으로 생성되는 수직\n"
              "탐색 메뉴가 있는 메인 인덱스가 포함됩니다. 비활성화하면 탐색 인덱스는 각 HTML 페이지에 정적으로 포함되는 여러 레벨의 탭으로\n"
              "구성됩니다. Qt 도움말 브라우저와 같이 JavaScript가 없는 브라우저를 지원하려면 이 옵션을 비활성화하세요.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "HTML_DYNAMIC_SECTIONS 태그가 YES 로 설정되면 생성된 HTML 문서에는 페이지가 로드된 후 숨기거나 표시할 수 있는\n"
              "섹션이 포함됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "HTML_CODE_FOLDING 태그가 YES 로 설정되면 클래스와 함수는 생성된 HTML 소스 코드에서 동적으로 접기 및 펼치기가\n"
              "가능합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "HTML_COPY_CLIPBOARD 태그가 YES 로 설정되면 Doxygen은 코드 및 텍스트 조각의 오른쪽 상단 모서리에 아이콘을\n"
              "표시하여 사용자가 내용을 클립보드에 복사할 수 있도록 합니다. 이는 브라우저에서 지원되고 웹 페이지가 보안 컨텍스트 (see:\n"
              "https://www.w3.org/TR/secure-contexts/)를 통해 제공되는 경우에만 작동합니다. 즉, https: 또는\n"
              "file: 프로토콜을 사용합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen은 브라우저에 몇 가지 설정을 영구적으로 저장합니다(예: 쿠키를 통해). 기본적으로 이러한 설정은 모든 프로젝트에서\n"
              "Doxygen에 의해 생성된 모든 HTML 페이지에 적용됩니다. HTML_PROJECT_COOKIE 태그를 사용하여 설정을 프로젝트별 키\n"
              "아래에 저장하여 사용자 기본 설정이 별도로 저장되도록 할 수 있습니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "HTML_INDEX_NUM_ENTRIES 를 사용하여 다양한 트리 구조 인덱스에 처음에 표시되는 항목의 선호 수를 제어할 수 있습니다.\n"
              "사용자는 나중에 항목을 동적으로 확장 및 축소할 수 있습니다. Doxygen은 지정된 수의 항목이 최대로 표시되는 수준까지 트리를\n"
              "확장합니다(완전히 축소된 트리가 이미 이 양을 초과하는 경우 제외). 따라서 항목 수를 1로 설정하면 기본적으로 완전히 축소된 트리가\n"
              "생성됩니다. 0은 무한한 항목 수를 나타내는 특수 값이며, 기본적으로 완전히 확장된 트리가 됩니다.\n"
              "최소값: 0, 최대값: 9999, 기본값: 100.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_DOCSET",
              "GENERATE_DOCSET 태그가 YES 로 설정되면 OSX 10.5(Leopard)에서 도입된 Apple의 Xcode 3 통합 개발\n"
              "환경 (see:\n"
              "https://developer.apple.com/xcode/)에 대한 입력으로 사용할 수 있는 추가 인덱스 파일이 생성됩니다. 문서 세트를\n"
              "생성하기 위해 Doxygen은 HTML 출력 디렉터리에 Makefile을 생성합니다. make 를 실행하면 해당 디렉터리에 docset이\n"
              "생성되고, make install을 실행하면 docset이\n"
              "~/Library/Developer/Shared/Documentation/DocSets에 설치되어 Xcode가 시작 시 이를 찾을 수\n"
              "있습니다. 자세한 내용은 https://developer.apple.com/library/archive/featuredarticles/Dox\n"
              "ygenXcode/_index.html을 참조하세요.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "이 태그는 docset 피드의 이름을 결정합니다. 문서 피드는 단일 공급자(회사 또는 제품 제품군 등)의 여러 문서 세트를 그룹화할 수 있는\n"
              "포괄적인 역할을 합니다.\n"
              "기본값은 Doxygen generated docs입니다.\n"
              "이 태그는 태그 GENERATE_DOCSET을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOCSET_FEEDURL",
              "이 태그는 docset 피드의 URL을 결정합니다. 문서 피드는 단일 공급자(회사 또는 제품 제품군 등)의 여러 문서 세트를 그룹화할 수\n"
              "있는 포괄적인 역할을 합니다.\n"
              "이 태그는 태그 GENERATE_DOCSET을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "이 태그는 문서 세트 번들을 고유하게 식별하는 문자열을 지정합니다. 역 도메인 이름 스타일의 문자열이어야 합니다. 예:\n"
              "com.mycompany.MyDocSet. Doxygen은 이름에 .docset을 추가합니다.\n"
              "기본값은 org.doxygen.Project입니다.\n"
              "이 태그는 태그 GENERATE_DOCSET을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "DOCSET_PUBLISHER_ID 태그는 문서 게시자를 고유하게 식별하는 문자열을 지정합니다. 역 도메인 이름 스타일의 문자열이어야\n"
              "합니다. 예: com.mycompany.MyDocSet.documentation.\n"
              "기본값은 org.doxygen.Publisher입니다.\n"
              "이 태그는 태그 GENERATE_DOCSET을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "DOCSET_PUBLISHER_NAME 태그는 문서 게시자를 식별합니다.\n"
              "기본값은 Publisher입니다.\n"
              "이 태그는 태그 GENERATE_DOCSET을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "GENERATE_HTMLHELP 태그가 YES 로 설정되면 Doxygen은 세 개의 추가 HTML 인덱스 파일을 생성합니다:\n"
              "index.hhp, index.hhc, 및 index.hhk. index.hhp 는 Windows의 Microsoft HTML 도움말\n"
              "워크샵에서 읽을 수 있는 프로젝트 파일입니다. 2021년 초 Microsoft는 원래 페이지를 오프라인으로 만들었습니다(HTML 도움말\n"
              "워크샵은 이미 몇 년 동안 유지 관리 모드였음). 웹 아카이브에서 HTML 도움말 워크샵을 다운로드할 수 있습니다: 설치 실행 파일\n"
              "(see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe).\n"
              "\n"
              "HTML 도움말 워크샵에는 Doxygen에 의해 생성된 모든 HTML 출력을 단일 컴파일된 HTML 파일(.chm)로 변환할 수 있는\n"
              "컴파일러가 포함되어 있습니다. 컴파일된 HTML 파일은 이제 Windows 98 도움말 형식으로 사용되며, 향후 모든 Windows\n"
              "플랫폼에서 이전 Windows 도움말 형식(.hlp)을 대체할 것입니다. 압축된 HTML 파일에는 인덱스와 목차도 포함되어 있으며, 문서에서\n"
              "단어를 검색할 수 있습니다. HTML 워크샵에는 압축된 HTML 파일의 뷰어도 포함되어 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "CHM_FILE",
              "CHM_FILE 태그를 사용하여 결과 .chm 파일의 파일 이름을 지정할 수 있습니다. 결과를 HTML 출력 디렉터리에 쓰지 않으려면 파일\n"
              "앞에 경로를 추가할 수 있습니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "HHC_LOCATION",
              "HHC_LOCATION 태그를 사용하여 HTML 도움말 컴파일러(hhc.exe)의 위치(파일 이름을 포함한 절대 경로)를 지정할 수\n"
              "있습니다. 비어 있지 않으면 Doxygen은 생성된 index.hhp 에서 HTML 도움말 컴파일러를 실행하려고 시도합니다.\n"
              "파일은 전체 경로로 지정해야 합니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_CHI",
              "GENERATE_CHI 플래그는 별도의 .chi 인덱스 파일이 생성되는지(YES) 또는 메인 .chm 파일에 포함되는지(NO)를\n"
              "제어합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "CHM_INDEX_ENCODING 은 HtmlHelp 인덱스(hhk), 콘텐츠(hhc) 및 프로젝트 파일의 콘텐츠를 인코딩하는 데\n"
              "사용됩니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "BINARY_TOC",
              "BINARY_TOC 플래그는 .chm 파일에서 바이너리 목차가 생성되는지(YES) 또는 일반 목차가 생성되는지(NO)를 제어합니다. 또한\n"
              "이전 및 다음 버튼을 활성화합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "TOC_EXPAND",
              "TOC_EXPAND 플래그를 YES 로 설정하면 HTML 도움말 문서의 목차와 트리 보기에 그룹 멤버에 대한 추가 항목이 추가됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTMLHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "SITEMAP_URL",
              "SITEMAP_URL 태그는 문서 배포 중에 사용자가 생성된 문서를 서버에 배치할 위치의 전체 URL을 지정하는 데 사용됩니다. 생성된\n"
              "사이트맵은 sitemap.xml이라고 하며 HTML_OUTPUT에서 지정된 디렉터리에 배치됩니다. SITEMAP_URL 이 지정되지 않으면\n"
              "사이트맵이 생성되지 않습니다. 사이트맵 프로토콜에 대한 자세한 내용은 https://www.sitemaps.org를 참조하세요.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_QHP",
              "GENERATE_QHP 태그가 YES 로 설정되고 QHP_NAMESPACE와 QHP_VIRTUAL_FOLDER가 모두 설정되면 생성된\n"
              "HTML 문서의 Qt 압축 도움말(.qch)을 생성하기 위해 Qt의 qhelpgenerator에 대한 입력으로 사용할 수 있는 추가 인덱스\n"
              "파일이 생성됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "QCH_FILE",
              "QHG_LOCATION 태그가 지정된 경우 QCH_FILE 태그를 사용하여 결과 .qch 파일의 파일 이름을 지정할 수 있습니다. 지정된\n"
              "경로는 HTML 출력 폴더에서의 상대 경로입니다.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHP_NAMESPACE",
              "QHP_NAMESPACE 태그는 Qt 도움말 프로젝트 출력을 생성할 때 사용할 네임스페이스를 지정합니다. 자세한 내용은 Qt 도움말\n"
              "프로젝트/네임스페이스 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace)를 참조하세요.\n"
              "기본값은 org.doxygen.Project입니다.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "QHP_VIRTUAL_FOLDER 태그는 Qt 도움말 프로젝트 출력을 생성할 때 사용할 네임스페이스를 지정합니다. 자세한 내용은 Qt\n"
              "도움말 프로젝트/가상 폴더 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders)를 참조하세요.\n"
              "기본값은 doc입니다.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "QHP_CUST_FILTER_NAME 태그가 설정되면 추가할 사용자 정의 필터의 이름을 지정합니다. 자세한 내용은 Qt 도움말\n"
              "프로젝트/사용자 정의 필터 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)를 참조하세요.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "QHP_CUST_FILTER_ATTRS 태그는 추가할 사용자 정의 필터의 속성 목록을 지정합니다. 자세한 내용은 Qt 도움말\n"
              "프로젝트/사용자 정의 필터 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)를 참조하세요.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "QHP_SECT_FILTER_ATTRS 태그는 이 프로젝트의 필터 섹션이 일치하는 속성 목록을 지정합니다. Qt 도움말 프로젝트/필터 속성\n"
              "(see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes).\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "QHG_LOCATION",
              "QHG_LOCATION 태그를 사용하여 Qt의 qhelpgenerator의 위치(파일 이름을 포함한 절대 경로)를 지정할 수 있습니다.\n"
              "비어 있지 않으면 Doxygen은 생성된 .qhp 파일에서 qhelpgenerator를 실행하려고 시도합니다.\n"
              "이 태그는 태그 GENERATE_QHP을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "GENERATE_ECLIPSEHELP 태그가 YES 로 설정되면 HTML 파일과 함께 추가 인덱스 파일이 생성되며, 이들은 Eclipse\n"
              "도움말 플러그인을 형성합니다. 이 플러그인을 설치하고 Eclipse의 도움말 콘텐츠 메뉴 아래에서 사용할 수 있도록 하려면 HTML 및\n"
              "XML 파일을 포함하는 디렉터리의 내용을 eclipse의 플러그인 디렉터리에 복사해야 합니다. 플러그인 디렉터리 내의 디렉터리 이름은\n"
              "ECLIPSE_DOC_ID 값과 같아야 합니다. 복사 후 Eclipse를 다시 시작해야 도움말이 나타납니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Eclipse 도움말 플러그인의 고유 식별자. 플러그인을 설치할 때 HTML 및 XML 파일을 포함하는 디렉터리 이름도 이 이름을 가져야\n"
              "합니다. 각 문서 세트에는 자체 식별자가 있어야 합니다.\n"
              "기본값은 org.doxygen.Project입니다.\n"
              "이 태그는 태그 GENERATE_ECLIPSEHELP을 YES로 설정해야 합니다."
          );
  doc->add(
              "DISABLE_INDEX",
              "생성된 HTML 페이지의 레이아웃을 완전히 제어하려는 경우 인덱스를 비활성화하고 자신만의 것으로 교체해야 할 수 있습니다.\n"
              "DISABLE_INDEX 태그를 사용하여 각 HTML 페이지 상단의 압축 인덱스(탭)를 켜거나 끌 수 있습니다. NO 값은 인덱스를\n"
              "활성화하고 YES 값은 비활성화합니다. 인덱스의 탭에는 탐색 트리와 동일한 정보가 포함되어 있으므로 GENERATE_TREEVIEW도 YES\n"
              "로 설정한 경우 이 옵션을 YES 로 설정할 수 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "GENERATE_TREEVIEW 태그는 계층 정보를 표시하기 위한 트리와 같은 인덱스 구조를 생성할지 여부를 지정하는 데 사용됩니다. 태그\n"
              "값이 YES 로 설정되면 트리와 같은 인덱스 구조를 포함하는 사이드 패널이 생성됩니다(HTML 도움말용으로 생성되는 것과 유사). 이것이\n"
              "작동하려면 JavaScript, DHTML, CSS 및 프레임을 지원하는 브라우저가 필요합니다(즉, 모든 최신 브라우저). Windows\n"
              "사용자는 HTML 도움말 기능을 사용하는 것이 더 나을 수 있습니다. 사용자 정의 스타일시트(HTML_EXTRA_STYLESHEET 참조)를\n"
              "통해 인덱스의 외관을 더 미세 조정할 수 있습니다(\"Fine-tuning the output\" 참조). 예를 들어, Doxygen에 의해\n"
              "생성된 기본 스타일시트에는 PROJECT_NAME 대신 트리의 루트에 이미지를 배치하는 방법을 보여주는 예가 있습니다. 트리는 기본적으로 탭\n"
              "인덱스보다 더 자세한 정보를 가지고 있으므로 이 옵션을 활성화할 때 DISABLE_INDEX를 YES 로 설정하는 것을 고려할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "GENERATE_TREEVIEW가 YES 로 설정된 경우 PAGE_OUTLINE_PANEL 옵션은 화면 오른쪽에 추가 탐색 패널을 표시할지\n"
              "여부를 결정하며, 메인 페이지의 콘텐츠 개요를 표시합니다(예: https://developer.android.com/reference).\n"
              "GENERATE_TREEVIEW가 NO 로 설정된 경우 이 옵션은 효과가 없습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "FULL_SIDEBAR",
              "GENERATE_TREEVIEW가 YES 로 설정된 경우 FULL_SIDEBAR 옵션은 사이드바가 트리 보기 영역에만 제한되는지(값 NO)\n"
              "또는 창의 전체 높이로 확장되는지(값 YES)를 결정합니다. 이것을 YES 로 설정하면 예를 들어\n"
              "https://docs.readthedocs.io와 유사한 레이아웃이 되며 콘텐츠를 위한 공간이 늘어나지만 프로젝트 로고, 제목 및 설명을\n"
              "위한 공간이 줄어듭니다. GENERATE_TREEVIEW가 NO 로 설정된 경우 이 옵션은 효과가 없습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "ENUM_VALUES_PER_LINE 태그를 사용하여 생성된 HTML 문서에서 Doxygen이 한 줄에 그룹화할 열거형 값의 수를 설정할\n"
              "수 있습니다.\n"
              "\n"
              "값이 0이면 개요 섹션에서 열거형 값이 완전히 억제됩니다.\n"
              "최소값: 0, 최대값: 20, 기본값: 4.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "SHOW_ENUM_VALUES 태그가 설정되면 Doxygen은 열거형 니모닉 옆에 지정된 열거형 값을 표시합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "트리 보기가 활성화된 경우(GENERATE_TREEVIEW 참조) 이 태그를 사용하여 트리가 표시되는 프레임의 초기 너비(픽셀)를 설정할 수\n"
              "있습니다.\n"
              "최소값: 0, 최대값: 1500, 기본값: 250.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "EXT_LINKS_IN_WINDOW 옵션이 YES 로 설정되면 Doxygen은 태그 파일을 통해 가져온 외부 기호에 대한 링크를 별도의\n"
              "창에서 엽니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "OBFUSCATE_EMAILS 태그가 YES 로 설정되면 Doxygen은 이메일 주소를 난독화합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "HTML_FORMULA_FORMAT 옵션이 svg 로 설정되면 Doxygen은 pdf2svg\n"
              "도구(https://github.com/dawbarton/pdf2svg 참조) 또는 inkscape(https://inkscape.org\n"
              "참조)를 사용하여 HTML 출력에서 PNG 대신 수식을 SVG 이미지로 생성합니다. 이러한 이미지는 일반적으로 확장된 해상도에서 더 잘\n"
              "보입니다.\n"
              "가능한 값:png (기본값)그리고svg (더 보기 좋지만 pdf2svg 또는 inkscape 도구 필요).\n"
              "기본값은 png입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "이 태그를 사용하여 HTML 문서에 이미지로 포함되는 LaTeX 수식의 글꼴 크기를 변경할 수 있습니다. Doxygen 실행이 성공한 후\n"
              "글꼴 크기를 변경하는 경우 강제로 다시 생성하기 위해 HTML 출력 디렉터리에서 모든 form_*.png 이미지를 수동으로 제거해야 합니다.\n"
              "최소값: 8, 최대값: 50, 기본값: 10.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "FORMULA_MACROFILE",
              "FORMULA_MACROFILE 에는 수식의 구성 요소로 사용되는 새로운 LaTeX 명령을 만들기 위한 LaTeX \\newcommand 및\n"
              "\\renewcommand 명령이 포함될 수 있습니다. 자세한 내용은 섹션 \"Including formulas\" 를 참조하세요."
          );
  doc->add(
              "USE_MATHJAX",
              "USE_MATHJAX 옵션을 활성화하면 사전 렌더링된 비트맵을 사용하는 대신 클라이언트 측 JavaScript를 사용하여 렌더링하는\n"
              "MathJax(https://www.mathjax.org 참조)를 사용하여 LaTeX 수식을 렌더링합니다. LaTeX가 설치되어 있지 않거나\n"
              "HTML 출력에서 수식을 더 보기 좋게 하려는 경우 사용합니다. 활성화한 경우 MathJax를 별도로 설치하고 MATHJAX_RELPATH\n"
              "옵션을 사용하여 경로를 설정해야 할 수도 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "MATHJAX_VERSION",
              "MATHJAX_VERSION 을 사용하여 사용할 MathJax 버전을 지정할 수 있습니다. MathJax의 다른 버전은 다른 설정에 대해\n"
              "다른 요구 사항을 가지므로 MathJax의 다른 버전 간에 전환할 때 다른 MathJax 설정도 변경해야 할 수 있습니다.\n"
              "가능한 값:MathJax_2, MathJax_3그리고MathJax_4.\n"
              "기본값은 MathJax_2입니다.\n"
              "이 태그는 태그 USE_MATHJAX을 YES로 설정해야 합니다."
          );
  doc->add(
              "MATHJAX_FORMAT",
              "MathJax가 활성화된 경우 MathJax 출력에 사용되는 기본 출력 형식을 설정할 수 있습니다. 출력 형식에 대한 자세한 내용은\n"
              "MathJax 버전 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html), MathJax 버전 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html), 및 MathJax 버전 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm)를 참조하세요.\n"
              "가능한 값:HTML-CSS (느리지만 최상의 호환성 제공. MathJax 버전 2의 이름이며, MathJax 버전 3에서는 chtml 로\n"
              "변환됨), NativeMML (즉, MathML. MathJax 2만 지원. MathJax 버전 3에서는 대신 chtml 이 사용됨.),\n"
              "chtml (MathJax 버전 3의 이름이며, MathJax 버전 2에서는 HTML-CSS로 변환됨)그리고SVG.\n"
              "기본값은 HTML-CSS입니다.\n"
              "이 태그는 태그 USE_MATHJAX을 YES로 설정해야 합니다."
          );
  doc->add(
              "MATHJAX_RELPATH",
              "MathJax가 활성화되면 MATHJAX_RELPATH 옵션을 사용하여 HTML 출력 디렉터리에 대한 상대 위치를 지정해야 합니다.\n"
              "MathJax 버전 2의 경우 대상 디렉터리에 MathJax.js 스크립트가 포함되어야 합니다. 예를 들어, mathjax 디렉터리가\n"
              "HTML 출력 디렉터리와 같은 수준에 있는 경우 MATHJAX_RELPATH 는 ../mathjax여야 합니다. MathJax 버전 3 및\n"
              "4의 경우 대상 디렉터리에 tex-<format>.js 스크립트(<format>은 chtml 또는 svg)가 포함되어야 합니다. 기본값은\n"
              "MathJax 콘텐츠 전송 네트워크를 가리키므로 MathJax를 설치하지 않고도 빠르게 결과를 볼 수 있습니다. 그러나 배포 전에\n"
              "https://www.mathjax.org에서 MathJax의 로컬 복사본을 설치하는 것이 강력히 권장됩니다. 기본값은：\n"
              "- MathJax 버전 2의 경우： https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- MathJax 버전 3의 경우： https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- MathJax 버전 4의 경우： https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "이 태그는 태그 USE_MATHJAX을 YES로 설정해야 합니다."
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "MATHJAX_EXTENSIONS 태그를 사용하여 MathJax 렌더링 중에 활성화할 하나 이상의 MathJax 확장 이름을 지정할 수\n"
              "있습니다. 예: MathJax 버전 2(https://docs.mathjax.org/en/v2.7/tex.html 참조):\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "예: MathJax 버전 3(https://docs.mathjax.org/en/v3.2/input/tex/extensions/ 참조):\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "예: MathJax 버전 4(https://docs.mathjax.org/en/v4.0/input/tex/extensions/ 참조):\n"
              "MATHJAX_EXTENSIONS = units\n"
              "Mathjax 버전 4에서는 꽤 많은 확장이 이미 자동으로 로드된다는 점에 유의하세요. Mathjax 버전 4에서 패키지를 비활성화하려면\n"
              "마이너스 기호가 앞에 온 패키지 이름을 사용할 수 있습니다(-, 예: MATHJAX_EXTENSIONS += -textmacros)\n"
              "이 태그는 태그 USE_MATHJAX을 YES로 설정해야 합니다."
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "MATHJAX_CODEFILE 태그를 사용하여 MathJax 코드의 시작 시 사용되는 JavaScript 코드 조각을 포함하는 파일을\n"
              "지정할 수 있습니다. 자세한 내용은 Mathjax 사이트를 참조하세요:\n"
              "- MathJax 버전 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax 버전 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax 버전 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)예시는 설명서를 참조하십시오.\n"
              "이 태그는 태그 USE_MATHJAX을 YES로 설정해야 합니다."
          );
  doc->add(
              "SEARCHENGINE",
              "SEARCHENGINE 태그가 활성화된 경우 Doxygen은 HTML 출력에 대한 검색 상자를 생성합니다. 기본 검색 엔진은\n"
              "JavaScript와 DHTML을 사용하며 모든 최신 브라우저에서 작동해야 합니다. HTML 도움말(GENERATE_HTMLHELP), Qt\n"
              "도움말(GENERATE_QHP) 또는 docsets(GENERATE_DOCSET)를 사용하는 경우 검색 기능이 이미 존재하므로 이것은\n"
              "일반적으로 비활성화해야 합니다. 대규모 프로젝트의 경우 JavaScript 기반 검색 엔진은 느릴 수 있으므로\n"
              "SERVER_BASED_SEARCH를 활성화하면 더 나은 솔루션이 제공될 수 있습니다. 키보드를 사용하여 검색할 수 있습니다. 검색 상자로\n"
              "이동하려면 <액세스 키> + S를 사용합니다(<액세스 키>가 무엇인지는 OS와 브라우저에 따라 다르지만 일반적으로 <CTRL>,\n"
              "<ALT>/<option> 또는 둘 다입니다). 검색 상자 내에서 <아래 커서 키>를 사용하여 검색 결과 창으로 이동하고 <커서 키>를\n"
              "사용하여 결과를 탐색할 수 있습니다. <Enter>를 눌러 항목을 선택하거나 <Esc>를 눌러 검색을 취소합니다. 커서가 검색 상자에 있을\n"
              "때 <Shift>+<아래 커서>를 누르면 필터 옵션을 선택할 수 있습니다. 여기서도 <커서 키>를 사용하여 필터를 선택하고 <Enter>\n"
              "또는 <Esc>를 눌러 필터 옵션을 활성화 또는 취소합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_HTML을 YES로 설정해야 합니다."
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "SERVER_BASED_SEARCH 태그가 활성화된 경우 검색 엔진은 JavaScript를 사용하는 웹 클라이언트 대신 웹 서버를 사용하여\n"
              "구현됩니다. EXTERNAL_SEARCH 설정에 따라 웹 서버 기반 검색에는 두 가지 유형이 있습니다. 비활성화된 경우 Doxygen은\n"
              "검색용 PHP 스크립트와 스크립트가 사용하는 인덱스 파일을 생성합니다. EXTERNAL_SEARCH가 활성화된 경우 인덱싱 및 검색은 외부\n"
              "도구에 의해 제공되어야 합니다. 자세한 내용은 섹션 \"External Indexing and Searching\" 를 참조하세요.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "EXTERNAL_SEARCH 태그가 활성화된 경우 Doxygen은 더 이상 검색용 PHP 스크립트를 생성하지 않습니다. 대신 검색 결과는\n"
              "XML 파일에 기록되며 외부 인덱서에 의해 처리되어야 합니다. Doxygen은 SEARCHENGINE_URL 옵션에서 지정된 외부 검색\n"
              "엔진을 호출하여 검색 결과를 가져옵니다.\n"
              "\n"
              "Doxygen에는 오픈 소스 검색 엔진 라이브러리 Xapian (see:\n"
              "https://xapian.org/)을 기반으로 하는 샘플 인덱서(doxyindexer)와 검색 엔진(doxysearch.cgi)이 포함되어\n"
              "있습니다.\n"
              "\n"
              "자세한 내용은 섹션 \"External Indexing and Searching\" 를 참조하세요.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "SEARCHENGINE_URL",
              "SEARCHENGINE_URL은 EXTERNAL_SEARCH가 활성화된 경우 검색 결과를 반환하는 웹 서버에 의해 호스팅되는 검색 엔진을\n"
              "가리켜야 합니다.\n"
              "\n"
              "Doxygen에는 오픈 소스 검색 엔진 라이브러리 Xapian (see:\n"
              "https://xapian.org/)을 기반으로 하는 샘플 인덱서(doxyindexer)와 검색 엔진(doxysearch.cgi)이 포함되어\n"
              "있습니다. 자세한 내용은 섹션 \"External Indexing and Searching\" 를 참조하세요.\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "SEARCHDATA_FILE",
              "SERVER_BASED_SEARCH와 EXTERNAL_SEARCH가 모두 활성화된 경우 인덱싱되지 않은 검색 데이터는 외부 도구에 의한\n"
              "인덱싱을 위해 파일에 기록됩니다. SEARCHDATA_FILE 태그로 이 파일의 이름을 지정할 수 있습니다.\n"
              "기본 파일은 searchdata.xml입니다.\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "SERVER_BASED_SEARCH와 EXTERNAL_SEARCH가 모두 활성화된 경우 EXTERNAL_SEARCH_ID 태그를 프로젝트의\n"
              "식별자로 사용할 수 있습니다. 이는 EXTRA_SEARCH_MAPPINGS와 결합하여 여러 프로젝트를 검색하고 결과를 올바른 프로젝트로\n"
              "리디렉션하는 데 유용합니다.\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "EXTRA_SEARCH_MAPPINGS 태그를 사용하여 이 구성 파일로 정의된 프로젝트 이외의 Doxygen 프로젝트를 검색할 수 있지만\n"
              "모두 동일한 외부 검색 인덱스에 추가됩니다. 각 프로젝트에는 EXTERNAL_SEARCH_ID를 통해 설정된 고유 ID가 있어야 합니다.\n"
              "검색 매핑은 ID를 문서를 찾을 수 있는 상대적 위치에 매핑합니다. 형식은:\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "이 태그는 태그 SEARCHENGINE을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_LATEX",
              "GENERATE_LATEX 태그가 YES 로 설정되면 Doxygen은 LaTeX 출력을 생성합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "LATEX_OUTPUT",
              "LATEX_OUTPUT 태그는 LaTeX 문서가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면\n"
              "OUTPUT_DIRECTORY의 값이 그 앞에 배치됩니다.\n"
              "기본 디렉토리는 latex입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_CMD_NAME",
              "LATEX_CMD_NAME 태그를 사용하여 호출할 LaTeX 명령 이름을 지정할 수 있습니다.\n"
              "\n"
              "USE_PDFLATEX를 활성화하지 않으면 기본값은 latex 입니다. USE_PDFLATEX를 활성화하면 기본값은 pdflatex 입니다.\n"
              "후자의 경우 latex 가 선택되면 pdflatex 로 덮어씌워집니다. 특정 출력 언어의 경우 기본값이 다르게 설정되었을 수 있으며, 이는\n"
              "출력 언어의 구현에 따라 다릅니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "MAKEINDEX_CMD_NAME 태그를 사용하여 LaTeX의 인덱스를 생성하는 명령 이름을 지정할 수 있습니다.\n"
              "참고: 이 태그는 Makefile / make.bat에서 사용됩니다.\n"
              "참조: 생성된 출력 파일(.tex)의 부분에 대해서는 LATEX_MAKEINDEX_CMD.\n"
              "기본 파일은 makeindex입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "LATEX_MAKEINDEX_CMD 태그를 사용하여 LaTeX의 인덱스를 생성하는 명령 이름을 지정할 수 있습니다. 첫 번째 문자로\n"
              "백슬래시(\\)가 없으면 LaTeX 코드에 자동으로 추가됩니다.\n"
              "참고: 이 태그는 생성된 출력 파일(.tex)에서 사용됩니다.\n"
              "참조: Makefile / make.bat의 부분에 대해서는 MAKEINDEX_CMD_NAME.\n"
              "기본값은 makeindex입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "COMPACT_LATEX",
              "COMPACT_LATEX 태그가 YES 로 설정되면 Doxygen은 더 컴팩트한 LaTeX 문서를 생성합니다. 이는 작은 프로젝트에\n"
              "유용하며 일반적으로 몇 그루의 나무를 절약하는 데 도움이 됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "PAPER_TYPE",
              "PAPER_TYPE 태그를 사용하여 프린터에서 사용되는 용지 유형을 설정할 수 있습니다.\n"
              "가능한 값:a4 (210 x 297 mm), letter (8.5 x 11 인치), legal (8.5 x 14 인치)그리고executive\n"
              "(7.25 x 10.5 인치).\n"
              "기본값은 a4입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXTRA_PACKAGES",
              "EXTRA_PACKAGES 태그를 사용하여 LaTeX 출력에 포함될 하나 이상의 LaTeX 패키지 이름을 지정할 수 있습니다. 패키지는\n"
              "이름만으로 지정하거나 LaTeX \\usepackage 명령에서 사용할 올바른 구문으로 지정할 수 있습니다. 예를 들어 times 글꼴을\n"
              "얻으려면 다음을 지정할 수 있습니다:\n"
              "EXTRA_PACKAGES=times 또는 EXTRA_PACKAGES={times}\n"
              "amsmath 패키지와 함께 intlimits 옵션을 사용하려면 다음을 지정할 수 있습니다:\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "비워 두면 추가 패키지가 포함되지 않습니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_HEADER",
              "LATEX_HEADER 태그를 사용하여 생성된 LaTeX 문서의 사용자 정의 LaTeX 헤더를 지정할 수 있습니다. 헤더는 첫 번째\n"
              "장까지의 모든 것을 포함해야 합니다. 비워 두면 Doxygen은 표준 헤더를 생성합니다. 다음을 사용하여 기본 헤더에서 시작하는 것이\n"
              "좋습니다:\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "그런 다음 파일 new_header.tex 를 수정하세요. Doxygen이 일반적으로 사용하는 기본 헤더 생성 방법에 대해서는 섹션\n"
              "\"Doxygen usage\" 도 참조하세요.\n"
              "\n"
              "참고: 자신이 무엇을 하고 있는지 이해하는 경우에만 사용자 정의 헤더를 사용하세요!\n"
              "참고: 헤더는 변경될 수 있으므로 일반적으로 Doxygen의 새 버전사용 가능한 마커 및 블록 이름에 대한 설명은 설명서를 참조하십시오.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_FOOTER",
              "LATEX_FOOTER 태그를 사용하여 생성된 LaTeX 문서의 사용자 정의 LaTeX 푸터를 지정할 수 있습니다. 푸터는 마지막 장\n"
              "이후의 모든 것을 포함해야 합니다. 비워 두면 Doxygen은 표준 푸터를 생성합니다. 기본 푸터 생성 방법과 푸터 내에서 사용할 수 있는\n"
              "특수 명령에 대한 자세한 내용은 LATEX_HEADER를 참조하세요. Doxygen이 일반적으로 사용하는 기본 푸터 생성 방법에 대해서는\n"
              "섹션 \"Doxygen usage\" 도 참조하세요. 참고: 자신이 무엇을 하고 있는지 이해하는 경우에만 사용자 정의 푸터를 사용하세요!\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "LATEX_EXTRA_STYLESHEET 태그를 사용하여 Doxygen에 의해 생성된 표준 스타일시트 이후에 포함되는 추가 사용자 정의\n"
              "LaTeX 스타일시트를 지정할 수 있습니다. 이 옵션을 사용하면 특정 스타일 측면을 재정의할 수 있습니다. Doxygen은 스타일시트 파일을\n"
              "출력 디렉터리에 복사합니다.\n"
              "참고: 추가 스타일시트 파일의 순서는 중요합니다(예: 목록의 마지막 스타일시트는 목록에서 이전 것의 설정을 재정의함).\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "LATEX_EXTRA_FILES 태그를 사용하여 LATEX_OUTPUT 출력 디렉터리에 복사될 하나 이상의 추가 이미지 또는 다른 소스\n"
              "파일을 지정할 수 있습니다. 파일은 있는 그대로 복사된다는 점에 유의하세요. 사용 가능한 명령이나 마커가 없습니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "PDF_HYPERLINKS",
              "PDF_HYPERLINKS 태그가 YES 로 설정되면 생성된 LaTeX는 PDF로 변환하기 위해 준비됩니다(ps2pdf 또는\n"
              "pdflatex 사용). PDF 파일에는 페이지 참조 대신 링크(HTML 출력과 유사)가 포함됩니다. 이를 통해 PDF 뷰어를 사용한 온라인\n"
              "브라우징에 적합한 출력이 됩니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "USE_PDFLATEX",
              "USE_PDFLATEX 태그가 YES 로 설정되면 Doxygen은 LATEX_CMD_NAME에서 지정된 엔진을 사용하여 LaTeX 파일에서\n"
              "직접 PDF 파일을 생성합니다. 더 고품질의 PDF 문서를 얻으려면 이 옵션을 YES 로 설정하세요.\n"
              "\n"
              "엔진 선택에 대해서는 섹션 LATEX_CMD_NAME도 참조하세요.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_BATCHMODE",
              "LATEX_BATCHMODE 태그는 오류가 발생한 경우 LaTeX의 동작을 알립니다.\n"
              "가능한 값:NO ERROR_STOP과 동일, YES BATCH와 동일, BATCH 배치 모드에서는 터미널에 아무것도 인쇄되지 않으며, 오류는\n"
              "각 오류에서 <return>이 눌린 것처럼 스크롤됩니다. TeX가 입력하거나 키보드 입력에서 요청하려는 누락된 파일(열리지 않은 입력\n"
              "스트림의 \\read)은 작업을 중단시킵니다, NON_STOP 비정지 모드에서는 진단 메시지가 터미널에 나타나지만, 배치 모드와 마찬가지로\n"
              "사용자 상호 작용이 불가능합니다, SCROLL 스크롤 모드에서 TeX는 입력할 파일이 누락되거나 키보드 입력이 필요한 경우에만\n"
              "중지합니다그리고ERROR_STOP 오류 정지 모드에서 TeX는 각 오류에서 중지하고 사용자 개입을 요청합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "LATEX_HIDE_INDICES 태그가 YES 로 설정되면 Doxygen은 출력에 인덱스 장(파일 인덱스, 컴파운드 인덱스 등)을\n"
              "포함하지 않습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "LATEX_BIB_STYLE 태그를 사용하여 참고 문헌에 사용할 스타일을 지정할 수 있습니다. 예: plainnat 또는 ieeetr.\n"
              "자세한 내용은 https://en.wikipedia.org/wiki/BibTeX 및 \\cite를 참조하세요.\n"
              "기본값은 plainnat입니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "LATEX_EMOJI_DIRECTORY 태그는 이모지 이미지가 로드되는 (상대 또는 절대) 경로를 지정하는 데 사용됩니다. 상대 경로가\n"
              "입력되면 LATEX_OUTPUT 디렉터리에서의 상대 경로가 됩니다. 비워 두면 LATEX_OUTPUT 디렉터리가 사용됩니다.\n"
              "이 태그는 태그 GENERATE_LATEX을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_RTF",
              "GENERATE_RTF 태그가 YES 로 설정되면 Doxygen은 RTF 출력을 생성합니다. RTF 출력은 Word 97용으로 최적화되어\n"
              "있으며 다른 RTF 리더/편집기에서는 그다지 예쁘지 않을 수 있습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "RTF_OUTPUT",
              "RTF_OUTPUT 태그는 RTF 문서가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면 OUTPUT_DIRECTORY의 값이\n"
              "그 앞에 배치됩니다.\n"
              "기본 디렉토리는 rtf입니다.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "COMPACT_RTF",
              "COMPACT_RTF 태그가 YES 로 설정되면 Doxygen은 더 컴팩트한 RTF 문서를 생성합니다. 이는 작은 프로젝트에 유용하며\n"
              "일반적으로 몇 그루의 나무를 절약하는 데 도움이 됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "RTF_HYPERLINKS",
              "RTF_HYPERLINKS 태그가 YES 로 설정되면 생성된 RTF에는 하이퍼링크 필드가 포함됩니다. RTF 파일에는 페이지 참조 대신\n"
              "링크(HTML 출력과 유사)가 포함됩니다. 이를 통해 Word 또는 이러한 필드를 지원하는 다른 Word 호환 리더를 사용한 온라인\n"
              "브라우징에 적합한 출력이 됩니다.\n"
              "\n"
              "참고: WordPad(write) 및 기타는 링크를 지원하지 않습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "파일에서 스타일시트 정의를 로드합니다. 구문은 Doxygen의 구성 파일과 유사하며 일련의 할당입니다. 재정의만 제공하면 되며 누락된 정의는\n"
              "기본값으로 설정됩니다.\n"
              "\n"
              "Doxygen이 일반적으로 사용하는 기본 스타일시트 생성 방법에 대해서는 섹션 \"Doxygen usage\" 도 참조하세요.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "RTF 문서의 생성에서 사용되는 선택적 변수를 정의합니다. 구문은 Doxygen의 구성 파일과 유사합니다. 템플릿 확장 파일은 doxygen\n"
              "-e rtf extensionFile를 사용하여 생성할 수 있습니다.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "RTF_EXTRA_FILES 태그를 사용하여 RTF_OUTPUT 출력 디렉터리에 복사될 하나 이상의 추가 이미지 또는 다른 소스 파일을\n"
              "지정할 수 있습니다. 파일은 있는 그대로 복사된다는 점에 유의하세요. 사용 가능한 명령이나 마커가 없습니다.\n"
              "이 태그는 태그 GENERATE_RTF을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_MAN",
              "GENERATE_MAN 태그가 YES 로 설정되면 Doxygen은 클래스와 파일의 매뉴얼 페이지를 생성합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "MAN_OUTPUT",
              "MAN_OUTPUT 태그는 매뉴얼 페이지가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면 OUTPUT_DIRECTORY의\n"
              "값이 그 앞에 배치됩니다. man3 디렉터리가 MAN_OUTPUT 에서 지정된 디렉터리 내에 생성됩니다.\n"
              "기본 디렉토리는 man입니다.\n"
              "이 태그는 태그 GENERATE_MAN을 YES로 설정해야 합니다."
          );
  doc->add(
              "MAN_EXTENSION",
              "MAN_EXTENSION 태그는 생성된 매뉴얼 페이지에 추가되는 확장자를 결정합니다. 매뉴얼 섹션이 숫자로 시작하지 않으면 숫자 3이 앞에\n"
              "추가됩니다. MAN_EXTENSION 태그의 선행 마침표(.)는 선택 사항입니다.\n"
              "기본값은 .3입니다.\n"
              "이 태그는 태그 GENERATE_MAN을 YES로 설정해야 합니다."
          );
  doc->add(
              "MAN_SUBDIR",
              "MAN_SUBDIR 태그는 매뉴얼 페이지가 배치되는 MAN_OUTPUT 내에 생성되는 디렉터리의 이름을 결정합니다. 기본적으로\n"
              "MAN_EXTENSION 의 선행 .이 제거된 것 뒤에 man이 옵니다.\n"
              "이 태그는 태그 GENERATE_MAN을 YES로 설정해야 합니다."
          );
  doc->add(
              "MAN_LINKS",
              "MAN_LINKS 태그가 YES 로 설정되고 Doxygen이 man 출력을 생성하는 경우 실제 매뉴얼 페이지 내의 문서화된 각 엔티티에\n"
              "대한 추가 man 파일이 생성됩니다. 이러한 추가 파일은 실제 매뉴얼 페이지만 소스하지만 없으면 man 명령이 올바른 페이지를 찾을 수\n"
              "없습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_MAN을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_XML",
              "GENERATE_XML 태그가 YES 로 설정되면 Doxygen은 코드 구조를 캡처하는 XML 파일을 생성하며 모든 문서를 포함합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "XML_OUTPUT",
              "XML_OUTPUT 태그는 XML 페이지가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면 OUTPUT_DIRECTORY의\n"
              "값이 그 앞에 배치됩니다.\n"
              "기본 디렉토리는 xml입니다.\n"
              "이 태그는 태그 GENERATE_XML을 YES로 설정해야 합니다."
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "XML_PROGRAMLISTING 태그가 YES 로 설정되면 Doxygen은 XML 출력에 프로그램 목록(구문 강조 및 상호 참조 정보\n"
              "포함)을 복사합니다. 이를 활성화하면 XML 출력의 크기가 크게 증가합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_XML을 YES로 설정해야 합니다."
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "XML_NS_MEMB_FILE_SCOPE 태그가 YES 로 설정되면 Doxygen은 파일 범위 내의 네임스페이스 멤버도 포함하며 HTML\n"
              "출력에 해당합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_XML을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "GENERATE_DOCBOOK 태그가 YES 로 설정되면 Doxygen은 PDF 생성에 사용할 수 있는 Docbook 파일을 생성합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "DOCBOOK_OUTPUT 태그는 Docbook 페이지가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면\n"
              "OUTPUT_DIRECTORY의 값이 그 앞에 배치됩니다.\n"
              "기본 디렉토리는 docbook입니다.\n"
              "이 태그는 태그 GENERATE_DOCBOOK을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "GENERATE_AUTOGEN_DEF 태그가 YES 로 설정되면 Doxygen은 코드 구조를 캡처하는 AutoGen 정의\n"
              "파일(https://autogen.sourceforge.net/ 참조)을 생성하며 모든 문서를 포함합니다. 이 기능은 아직 실험적이며 현재\n"
              "불완전합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "GENERATE_SQLITE3",
              "GENERATE_SQLITE3 태그가 YES 로 설정되면 Doxygen은 Sqlite3 데이터베이스를 생성하며 Doxygen에 의해 발견된\n"
              "기호가 테이블에 저장됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "SQLITE3_OUTPUT 태그는 Sqlite3 데이터베이스가 배치될 위치를 지정하는 데 사용됩니다. 상대 경로가 입력되면\n"
              "OUTPUT_DIRECTORY의 값이 그 앞에 배치됩니다.\n"
              "기본 디렉토리는 sqlite3입니다.\n"
              "이 태그는 태그 GENERATE_SQLITE3을 YES로 설정해야 합니다."
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "SQLITE3_RECREATE_DB 태그가 YES 로 설정되면 기존 doxygen_sqlite3.db 데이터베이스 파일은 Doxygen이\n"
              "실행될 때마다 다시 생성됩니다. NO 로 설정되면 Doxygen은 데이터베이스 파일이 이미 발견된 경우 경고하고 수정하지 않습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_SQLITE3을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_PERLMOD",
              "GENERATE_PERLMOD 태그가 YES 로 설정되면 Doxygen은 코드 구조를 캡처하는 Perl 모듈 파일을 생성하며 모든 문서를\n"
              "포함합니다.\n"
              "\n"
              "이 기능은 아직 실험적이며 현재 불완전합니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "PERLMOD_LATEX",
              "PERLMOD_LATEX 태그가 YES 로 설정되면 Doxygen은 필요한 Makefile 규칙, Perl 스크립트 및 LaTeX 코드를\n"
              "생성하여 Perl 모듈 출력에서 PDF 및 DVI 출력을 생성할 수 있도록 합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 GENERATE_PERLMOD을 YES로 설정해야 합니다."
          );
  doc->add(
              "PERLMOD_PRETTY",
              "PERLMOD_PRETTY 태그가 YES 로 설정되면 Perl 모듈 출력은 사람이 읽을 수 있도록 예쁘게 형식화됩니다. 이는 무슨 일이\n"
              "일어나고 있는지 이해하려는 경우에 편리합니다. 반면에 이 태그가 NO 로 설정되면 Perl 모듈 출력의 크기가 훨씬 작아지며 Perl은\n"
              "동일하게 구문 분석합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 GENERATE_PERLMOD을 YES로 설정해야 합니다."
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "생성된 doxyrules.make 파일의 make 변수 이름은 PERLMOD_MAKEVAR_PREFIX 에 포함된 문자열이 앞에 옵니다.\n"
              "이는 동일한 Makefile에 포함된 다른 doxyrules.make 파일이 서로의 변수를 덮어쓰지 않도록 하는 데 유용합니다.\n"
              "이 태그는 태그 GENERATE_PERLMOD을 YES로 설정해야 합니다."
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "ENABLE_PREPROCESSING 태그가 YES 로 설정되면 Doxygen은 소스 및 포함 파일에서 발견된 모든 C 전처리기 지시문을\n"
              "평가합니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "MACRO_EXPANSION",
              "MACRO_EXPANSION 태그가 YES 로 설정되면 Doxygen은 소스 코드의 모든 매크로 이름을 확장합니다. NO 로 설정되면\n"
              "조건부 컴파일만 수행됩니다. 매크로 확장은 EXPAND_ONLY_PREDEF를 YES 로 설정하여 제어된 방식으로 수행할 수 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "EXPAND_ONLY_PREDEF 및 MACRO_EXPANSION 태그가 모두 YES 로 설정되면 매크로 확장은 PREDEFINED 및\n"
              "EXPAND_AS_DEFINED 태그로 지정된 매크로로 제한됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "SEARCH_INCLUDES",
              "SEARCH_INCLUDES 태그가 YES 로 설정되면 #include 가 발견된 경우 INCLUDE_PATH의 포함 파일이 검색됩니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "INCLUDE_PATH",
              "INCLUDE_PATH 태그를 사용하여 입력 파일이 아니지만 전처리기에 의해 처리되어야 하는 포함 파일을 포함하는 하나 이상의 디렉터리를\n"
              "지정할 수 있습니다. INCLUDE_PATH 는 재귀적이지 않으므로 RECURSIVE의 설정은 여기서 효과가 없습니다.\n"
              "이 태그는 태그 SEARCH_INCLUDES을 YES로 설정해야 합니다."
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "INCLUDE_FILE_PATTERNS 태그를 사용하여 디렉터리 내의 헤더 파일을 필터링하는 하나 이상의 와일드카드 패턴(*.h 및\n"
              "*.hpp처럼)을 지정할 수 있습니다. 비워 두면 FILE_PATTERNS에서 지정된 패턴이 사용됩니다.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "PREDEFINED",
              "PREDEFINED 태그를 사용하여 전처리기가 시작되기 전에 정의되는 하나 이상의 매크로 이름을 지정할 수 있습니다(예: gcc 의 -D\n"
              "옵션과 유사). 태그의 인수는 name 또는 name=definition 형식의 매크로 목록입니다(공백 없음). 정의와 =가 생략된 경우\n"
              "=1이 가정됩니다. 매크로 정의가 #undef 를 통해 정의 해제되거나 재귀적으로 확장되는 것을 방지하려면 = 연산자 대신 := 연산자를\n"
              "사용하세요.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "MACRO_EXPANSION 및 EXPAND_ONLY_PREDEF 태그가 YES 로 설정된 경우 이 태그를 사용하여 확장할 매크로 이름\n"
              "목록을 지정할 수 있습니다. 소스에서 발견된 매크로 정의가 사용됩니다. 소스 코드에서 발견된 정의를 재정의하는 다른 매크로 정의를 사용하려면\n"
              "PREDEFINED 태그를 사용하세요.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "SKIP_FUNCTION_MACROS 태그가 YES 로 설정되면 Doxygen의 전처리기는 줄에 단독으로 있고, 모두 대문자 이름을\n"
              "가지며, 세미콜론으로 끝나지 않는 함수형 매크로에 대한 모든 참조를 제거합니다. 그러한 함수 매크로는 일반적으로 상용구 코드에 사용되며\n"
              "제거되지 않으면 파서를 혼란스럽게 합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 ENABLE_PREPROCESSING을 YES로 설정해야 합니다."
          );
  doc->add(
              "TAGFILES",
              "TAGFILES 태그를 사용하여 하나 이상의 태그 파일을 지정할 수 있습니다. 각 태그 파일에 대해 외부 문서의 위치를 추가해야 합니다.\n"
              "위치 없는 태그 파일의 형식은 다음과 같습니다:\n"
              "TAGFILES = file1 file2 ...\n"
              "태그 파일의 위치 추가는 다음과 같이 수행됩니다:\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "여기서 loc1과 loc2는 상대 경로, 절대 경로 또는 URL이 될 수 있습니다. 태그 파일 사용에 대한 자세한 내용은 섹션\n"
              "\"Linking to external documentation\" 을 참조하세요.\n"
              "참고: 각 태그 파일은 고유한 이름을 가져야 합니다(또는 이름은 경로를 포함하지 않음). 태그 파일이 Doxygen이 실행되는 디렉터리에\n"
              "없는 경우 여기서 태그 파일의 경로도 지정해야 합니다."
          );
  doc->add(
              "GENERATE_TAGFILE",
              "GENERATE_TAGFILE 뒤에 파일 이름이 지정되면 Doxygen은 읽은 입력 파일을 기반으로 태그 파일을 생성합니다. 태그 파일\n"
              "사용에 대한 자세한 내용은 섹션 \"Linking to external documentation\" 을 참조하세요."
          );
  doc->add(
              "ALLEXTERNALS",
              "ALLEXTERNALS 태그가 YES 로 설정되면 모든 외부 클래스와 네임스페이스가 클래스 및 네임스페이스 인덱스에 나열됩니다. NO 로\n"
              "설정되면 상속된 외부 클래스만 나열됩니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "EXTERNAL_GROUPS 태그가 YES 로 설정되면 모든 외부 그룹이 주제 인덱스에 나열됩니다. NO 로 설정되면 현재 프로젝트의\n"
              "그룹만 나열됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "EXTERNAL_PAGES",
              "EXTERNAL_PAGES 태그가 YES 로 설정되면 모든 외부 페이지가 관련 페이지 인덱스에 나열됩니다. NO 로 설정되면 현재\n"
              "프로젝트의 페이지만 나열됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "YES 로 설정되면 상속 및 협업 그래프는 대상이 문서화되지 않았거나 클래스가 아닌 경우 상속 및 사용 관계를 숨깁니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "HAVE_DOT",
              "HAVE_DOT 태그를 YES 로 설정하면 Doxygen은 path 에서 dot 도구를 사용할 수 있다고 가정합니다. 이 도구는 AT&T\n"
              "및 Lucent Bell Labs의 Graphviz (see:\n"
              "https://www.graphviz.org/) 그래프 시각화 도구 키트의 일부입니다. 이 옵션이 NO 로 설정되면 이 섹션의 다른 옵션은\n"
              "효과가 없습니다.\n"
              "기본값은 NO입니다."
          );
  doc->add(
              "DOT_NUM_THREADS",
              "DOT_NUM_THREADS 는 Doxygen이 병렬로 실행을 허용하는 dot 호출 수를 지정합니다. 0 으로 설정하면 Doxygen은\n"
              "시스템에서 사용 가능한 프로세서 수에 따라 설정합니다. CPU 부하와 처리 속도의 균형을 더 제어하기 위해 0보다 큰 값으로 명시적으로\n"
              "설정할 수 있습니다.\n"
              "최소값: 0, 최대값: 512, 기본값: 0.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "DOT_BATCH_SIZE 는 Doxygen이 단일 dot 호출에서 컴파일할 수 있는 dot 그래프의 수를 지정합니다. 1 로 설정하면\n"
              "Doxygen은 각 그래프에 대해 별도로 dot 을 호출하며, 이는 특히 많은 CPU 코어가 있는 시스템에서 상당한 프로세스 생성 오버헤드를\n"
              "유발할 수 있습니다. DOT_NUM_THREADS 와 함께 이 설정을 사용하여 특정 시스템의 dot 처리 속도를 최적화할 수 있습니다.\n"
              "Doxygen은 각 스레드에 균형 잡힌 작업량을 할당하려고 시도합니다. 처리할 그래프의 총 수가 DOT_NUM_THREADS *\n"
              "DOT_BATCH_SIZE를 초과하면 dot 이 처리할 추가 배치가 생성됩니다.\n"
              "최소값: 1, 최대값: 1000, 기본값: 50.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR 는 노드, 에지 및 서브그래프 레이블의 공통 속성입니다. Doxygen이 생성하는 dot 파일에서 다른 외관의\n"
              "글꼴을 사용하려면 fontname, fontcolor 및 fontsize 속성을 지정할 수 있습니다. 자세한 내용은 <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>노드, 에지 및 그래프 속성 사양</a>을 참조하세요.\n"
              "dot이 글꼴을 찾을 수 있는지 확인해야 합니다. 이는 표준 위치에 배치하거나 DOTFONTPATH 환경 변수를 설정하거나 글꼴을 포함하는\n"
              "디렉터리에 DOT_FONTPATH를 설정하여 수행할 수 있습니다. graphviz의 기본 글꼴 크기는 14입니다.\n"
              "기본값은 fontname=Helvetica,fontsize=10입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR 는 DOT_COMMON_ATTR와 연결됩니다. 우아한 스타일을 위해 'arrowhead=open,\n"
              "arrowtail=open, arrowsize=0.5'를 추가할 수 있습니다. <a\n"
              "href=https://graphviz.org/doc/info/arrows.html>화살표 모양의 전체 문서.</a>\n"
              "기본값은 labelfontname=Helvetica,labelfontsize=10입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR 는 DOT_COMMON_ATTR와 연결됩니다. 노드 주위의 상자 없는 보기를 위해 'shape=plain' 또는\n"
              "'shape=plaintext'를 설정합니다. <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>모양 사양.</a>\n"
              "기본값은 shape=box,height=0.2,width=0.4입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_FONTPATH",
              "DOT_COMMON_ATTR 및 다른 dot 속성에서 fontname으로 지정된 글꼴을 dot이 찾을 수 있는 경로를 설정할 수 있습니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "CLASS_GRAPH",
              "CLASS_GRAPH 태그가 YES 또는 GRAPH 또는 BUILTIN 으로 설정되면 Doxygen은 문서화된 각 클래스의 그래프를\n"
              "생성하여 직접 및 간접 상속 관계를 보여줍니다. CLASS_GRAPH 태그가 YES 또는 GRAPH 로 설정되고 HAVE_DOT도 활성화된\n"
              "경우 dot이 그래프를 그리는 데 사용됩니다. CLASS_GRAPH 태그가 YES 로 설정되고 HAVE_DOT이 비활성화된 경우 또는\n"
              "CLASS_GRAPH 태그가 BUILTIN 으로 설정된 경우 내장 생성기가 사용됩니다. CLASS_GRAPH 태그가 TEXT 로 설정된 경우\n"
              "직접 및 간접 상속 관계가 텍스트/링크로 표시됩니다. 특정 클래스의 상속 그래프를 명시적으로 활성화하거나 다른 표현을 선택하려면\n"
              "\\inheritancegraph 명령을 사용할 수 있습니다. 상속 그래프를 비활성화하려면 \\hideinheritancegraph 명령을\n"
              "사용할 수 있습니다.\n"
              "가능한 값:NO, YES, TEXT, GRAPH그리고BUILTIN.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "COLLABORATION_GRAPH 태그가 YES 로 설정되면 Doxygen은 문서화된 각 클래스의 그래프를 생성하여 클래스와 다른\n"
              "문서화된 클래스 간의 직접 및 간접 구현 종속성(상속, 포함 및 클래스 참조 변수)을 보여줍니다. COLLABORATION_GRAPH 가\n"
              "NO 로 설정된 경우 협업 그래프를 명시적으로 활성화하려면 \\collaborationgraph 명령을 사용할 수 있습니다. 협업 그래프를\n"
              "비활성화하려면 \\hidecollaborationgraph 명령을 사용할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "GROUP_GRAPHS",
              "GROUP_GRAPHS 태그가 YES 로 설정되면 Doxygen은 그룹의 그래프를 생성하여 그룹의 직접 종속성을 보여줍니다.\n"
              "GROUP_GRAPHS 가 NO 로 설정된 경우 그룹 종속 그래프를 명시적으로 활성화하려면 \\groupgraph 명령을 사용할 수 있습니다.\n"
              "디렉터리 그래프를 비활성화하려면 \\hidegroupgraph 명령을 사용할 수 있습니다. 매뉴얼의 그룹화 장도 참조하세요.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "UML_LOOK",
              "UML_LOOK 태그가 YES 로 설정되면 Doxygen은 OMG의 통합 모델링 언어와 유사한 스타일로 상속 및 협업 다이어그램을\n"
              "생성합니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "UML_LOOK 태그가 활성화된 경우 필드와 메서드는 클래스 노드 내에 표시됩니다. 많은 필드 또는 메서드와 많은 노드가 있는 경우 그래프가\n"
              "유용하지 않을 정도로 커질 수 있습니다. UML_LIMIT_NUM_FIELDS 임계값은 크기를 더 관리하기 쉽게 만들기 위해 각 유형의 요소\n"
              "수를 제한합니다. 제한 없이 0으로 설정합니다. 임계값은 제한이 적용되기 전에 50% 초과할 수 있습니다. 따라서 임계값을 10으로 설정하면\n"
              "최대 15개 필드가 나타날 수 있지만 수가 15를 초과하면 표시되는 총 필드 수는 10으로 제한됩니다.\n"
              "최소값: 0, 최대값: 100, 기본값: 10.\n"
              "이 태그는 태그 UML_LOOK을 YES로 설정해야 합니다."
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "UML_LOOK 태그가 활성화된 경우 필드 레이블은 두 클래스 노드 사이의 에지를 따라 표시됩니다. 많은 필드와 많은 노드가 있는 경우\n"
              "그래프가 너무 복잡해질 수 있습니다. UML_MAX_EDGE_LABELS 임계값은 크기를 더 관리하기 쉽게 만들기 위해 요소 수를\n"
              "제한합니다. 제한 없이 0으로 설정합니다.\n"
              "최소값: 0, 최대값: 100, 기본값: 10.\n"
              "이 태그는 태그 UML_LOOK을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_UML_DETAILS",
              "DOT_UML_DETAILS 태그가 NO 로 설정되면 Doxygen은 UML 그래프에서 유형 및 인수 없이 속성과 메서드를 표시합니다.\n"
              "DOT_UML_DETAILS 태그가 YES 로 설정되면 Doxygen은 UML 그래프에서 속성과 메서드의 유형 및 인수를 추가합니다.\n"
              "DOT_UML_DETAILS 태그가 NONE 으로 설정되면 Doxygen은 UML 그래프에서 클래스 멤버 정보가 있는 필드를 생성하지\n"
              "않습니다. 클래스 다이어그램은 기본 클래스 다이어그램과 유사하지만 관계에 UML 표기법을 사용합니다.\n"
              "가능한 값:NO, YES그리고NONE.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 UML_LOOK을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "DOT_WRAP_THRESHOLD 태그를 사용하여 한 줄에 표시되는 최대 문자 수를 설정할 수 있습니다. 실제 줄 길이가 이 임계값을 크게\n"
              "초과하면 여러 줄로 나뉩니다. 보기 흉한 줄 바꿈을 피하기 위해 몇 가지 휴리스틱이 적용됩니다.\n"
              "최소값: 0, 최대값: 1000, 기본값: 17.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "TEMPLATE_RELATIONS 태그가 YES 로 설정되면 상속 및 협업 그래프는 템플릿과 해당 인스턴스 간의 관계를 보여줍니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "INCLUDE_GRAPH",
              "INCLUDE_GRAPH, ENABLE_PREPROCESSING 및 SEARCH_INCLUDES 태그가 모두 YES 로 설정되면\n"
              "Doxygen은 문서화된 각 파일의 그래프를 생성하여 파일과 다른 문서화된 파일 간의 직접 및 간접 포함 종속성을 보여줍니다.\n"
              "INCLUDE_GRAPH 가 NO 로 설정된 경우 포함 그래프를 명시적으로 활성화하려면 \\includegraph 명령을 사용할 수 있습니다.\n"
              "포함 그래프를 비활성화하려면 \\hideincludegraph 명령을 사용할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING 및 SEARCH_INCLUDES 태그가 모두 YES 로 설정되면\n"
              "Doxygen은 문서화된 각 파일의 그래프를 생성하여 파일과 다른 문서화된 파일 간의 직접 및 간접 포함 종속성을 보여줍니다.\n"
              "INCLUDED_BY_GRAPH 가 NO 로 설정된 경우 포함된 그래프를 명시적으로 활성화하려면 \\includedbygraph 명령을 사용할\n"
              "수 있습니다. 포함된 그래프를 비활성화하려면 \\hideincludedbygraph 명령을 사용할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "CALL_GRAPH",
              "CALL_GRAPH 태그가 YES 로 설정되면 Doxygen은 각 전역 함수 또는 클래스 메서드에 대한 호출 종속성 그래프를 생성합니다.\n"
              "\n"
              "이 옵션을 활성화하면 실행 시간이 크게 증가합니다. 따라서 대부분의 경우 \\callgraph 명령을 사용하여 선택한 함수에 대해서만 호출\n"
              "그래프를 활성화하는 것이 좋습니다. 호출 그래프를 비활성화하려면 \\hidecallgraph 명령을 사용할 수 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "CALLER_GRAPH",
              "CALLER_GRAPH 태그가 YES 로 설정되면 Doxygen은 각 전역 함수 또는 클래스 메서드에 대한 호출자 종속성 그래프를\n"
              "생성합니다.\n"
              "\n"
              "이 옵션을 활성화하면 실행 시간이 크게 증가합니다. 따라서 대부분의 경우 \\callergraph 명령을 사용하여 선택한 함수에 대해서만\n"
              "호출자 그래프를 활성화하는 것이 좋습니다. 호출자 그래프를 비활성화하려면 \\hidecallergraph 명령을 사용할 수 있습니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "GRAPHICAL_HIERARCHY 태그가 YES 로 설정되면 Doxygen은 텍스트 대신 모든 클래스의 그래픽 계층 구조를 생성합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "DIRECTORY_GRAPH 태그가 YES 로 설정되면 Doxygen은 디렉터리의 다른 디렉터리에 대한 종속성을 그래픽으로 보여줍니다.\n"
              "종속성 관계는 디렉터리 내의 파일 간의 #include 관계에 의해 결정됩니다. DIRECTORY_GRAPH 가 NO 로 설정된 경우\n"
              "디렉터리 그래프를 명시적으로 활성화하려면 \\directorygraph 명령을 사용할 수 있습니다. 디렉터리 그래프를 비활성화하려면\n"
              "\\hidedirectorygraph 명령을 사용할 수 있습니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "DIR_GRAPH_MAX_DEPTH 태그를 사용하여 dot 에 의해 생성되는 디렉터리 종속성 그래프에서 생성되는 하위 디렉터리 레벨의 최대\n"
              "수를 제한할 수 있습니다.\n"
              "최소값: 1, 최대값: 25, 기본값: 1.\n"
              "이 태그는 태그 DIRECTORY_GRAPH을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "DOT_IMAGE_FORMAT 태그를 사용하여 dot 에 의해 생성되는 이미지의 이미지 형식을 설정할 수 있습니다. 이미지 형식에 대한\n"
              "설명은 dot 도구 문서의 출력 형식 섹션을 참조하세요(Graphviz (see:\n"
              "https://www.graphviz.org/)).\n"
              "\n"
              "svg:cairo 및 svg:cairo:cairo 형식은 INTERACTIVE_SVG와 함께 사용할 수\n"
              "없습니다(INTERACTIVE_SVG는 NO로 설정됨).\n"
              "가능한 값:png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo, png:cairo:gd,\n"
              "png:cairo:cairo, png:cairo:gdiplus, png:gdiplus, png:gdiplus:gdiplus,\n"
              "svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core, gif:cairo, gif:cairo:gd,\n"
              "gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus, gif:gd, gif:gd:gd,\n"
              "jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd, jpg:gd:gd,\n"
              "jpg:gdiplus그리고jpg:gdiplus:gdiplus.\n"
              "기본값은 png입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "INTERACTIVE_SVG",
              "DOT_IMAGE_FORMAT이 svg 또는 svg:svg 또는 svg:svg:core로 설정된 경우 이 옵션을 YES 로 설정하여 확대 및\n"
              "이동이 가능한 대화형 SVG 이미지 생성을 활성화할 수 있습니다.\n"
              "\n"
              "Internet Explorer 이외의 최신 브라우저가 필요합니다. 테스트되어 작동하는 것: Firefox, Chrome, Safari 및\n"
              "Opera.\n"
              "\n"
              "DOT_IMAGE_FORMAT이 svg:cairo 또는 svg:cairo:cairo로 설정된 경우 이 옵션은 자동으로 비활성화됩니다.\n"
              "기본값은 NO입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_PATH",
              "DOT_PATH 태그를 사용하여 dot 도구를 찾을 수 있는 경로를 지정할 수 있습니다. 비워 두면 dot 도구가 path 에서 찾을 수\n"
              "있다고 가정합니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOTFILE_DIRS",
              "DOTFILE_DIRS 태그를 사용하여 문서에 포함될 dot 파일을 포함하는 하나 이상의 디렉터리를 지정할 수 있습니다(\\dotfile\n"
              "명령 참조).\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DIA_PATH",
              "문서에 dia로 만든 다이어그램을 포함할 수 있습니다. Doxygen은 dia를 실행하여 다이어그램을 생성하고 문서에 삽입합니다.\n"
              "DIA_PATH 태그를 사용하면 dia 바이너리가 있는 디렉터리를 지정할 수 있습니다. 비워 두면 dia는 기본 검색 경로에서 찾을 수\n"
              "있다고 가정합니다."
          );
  doc->add(
              "DIAFILE_DIRS",
              "DIAFILE_DIRS 태그를 사용하여 문서에 포함될 dia 파일을 포함하는 하나 이상의 디렉터리를 지정할 수 있습니다(\\diafile\n"
              "명령 참조)."
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "PlantUML을 사용하는 경우 PLANTUML_JAR_PATH 태그를 사용하여 java가 plantuml.jar 파일 또는 사용할 jar\n"
              "파일의 파일 이름을 찾을 수 있는 경로를 지정해야 합니다. 비워 두면 PlantUML이 사용되지 않거나 전처리 단계에서 호출된다고\n"
              "가정합니다. 이 경우 Doxygen은 \\startuml 명령을 만나면 경고를 생성하고 다이어그램에 대한 출력을 생성하지 않습니다."
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "PlantUML을 사용하는 경우 PLANTUML_CFG_FILE 태그를 사용하여 PlantUML의 구성 파일을 지정할 수 있습니다."
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "PlantUML을 사용하는 경우 지정된 경로는 PlantUML 블록 내의 !include 문에 지정된 파일에 대해 검색됩니다."
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "PLANTUMLFILE_DIRS 태그를 사용하여 문서에 포함될 PlantUml 파일을 포함하는 하나 이상의 디렉터리를 지정할 수\n"
              "있습니다(\\plantumlfile 명령 참조)."
          );
  doc->add(
              "MERMAID_PATH",
              "CLI 렌더링으로 Mermaid 다이어그램을 사용하는 경우 MERMAID_PATH 태그를 사용하여 mmdc(Mermaid CLI) 실행\n"
              "파일을 찾을 수 있는 디렉터리를 지정해야 합니다. 비워 두면 CLI 기반 렌더링이 비활성화됩니다. HTML 출력의 경우 JavaScript를\n"
              "통한 클라이언트 측 렌더링이 기본적으로 사용되며 mmdc 가 필요하지 않습니다. LaTeX/PDF 출력의 경우 이미지를 미리 생성하기 위해\n"
              "mmdc 가 필요합니다. CLI 렌더링이 필요하지만 mmdc 를 사용할 수 없는 경우 Doxygen은 경고를 생성합니다."
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "Mermaid 다이어그램을 사용하는 경우 MERMAID_CONFIG_FILE 태그를 사용하여 Mermaid CLI 도구(mmdc)에 대한\n"
              "JSON 구성 파일을 지정할 수 있습니다. 이 파일에는 테마 설정 및 기타 Mermaid 구성 옵션이 포함될 수 있습니다."
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "MERMAID_RENDER_MODE 태그는 Mermaid 다이어그램이 렌더링되는 방식을 선택합니다.\n"
              "가능한 값:AUTO (HTML은 클라이언트 측 렌더링 사용, LaTeX/PDF 및 기타 형식은 mmdc 사용. MERMAID_PATH 가\n"
              "설정되지 않은 경우 비 HTML 다이어그램은 경고를 생성함), CLI (mmdc 도구를 사용하여 이미지 사전 생성(Node.js 및\n"
              "mermaid-js/mermaid-cli 필요). 모든 출력 형식에서 작동)그리고CLIENT_SIDE (클라이언트 측 렌더링을 위해\n"
              "mermaid.js 를 HTML 출력에 포함. mmdc 가 필요 없지만 HTML 출력에서만 작동).\n"
              "기본값은 AUTO입니다."
          );
  doc->add(
              "MERMAID_JS_URL",
              "MERMAID_JS_URL 태그는 클라이언트 측 렌더링을 사용하는 경우(MERMAID_RENDER_MODE 가 CLIENT_SIDE 또는\n"
              "AUTO) mermaid.js 를 로드할 URL을 지정합니다. 기본값은 jsDelivr CDN의 최신 Mermaid v11을 가리킵니다.\n"
              "\n"
              "기본 CDN URL은 생성된 문서를 볼 때 인터넷 액세스가 필요합니다. 오프라인 사용의 경우 mermaid.esm.min.mjs 를\n"
              "다운로드하고 이것을 상대 경로로 설정하거나 대신 MERMAID_RENDER_MODE=CLI 를 사용하여 이미지를 미리 생성하세요.\n"
              "예:\n"
              "- 최신 v11(기본값):\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- 고정된 버전:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs\n"
              "- 로컬 복사본: ./mermaid.esm.min.mjs(사용자는 파일을 HTML 출력 디렉터리에 배치해야 함)\n"
              "기본값은 https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs입니다."
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "MERMAIDFILE_DIRS 태그를 사용하여 문서에 포함될 Mermaid 파일을 포함하는 하나 이상의 디렉터리를 지정할 수\n"
              "있습니다(\\mermaidfile 명령 참조)."
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "DOT_GRAPH_MAX_NODES 태그를 사용하여 그래프에 표시될 노드의 최대 수를 설정할 수 있습니다. 그래프의 노드 수가 이 값을\n"
              "초과하면 Doxygen은 그래프를 잘라내고 노드를 빨간 상자로 표시하여 시각화합니다. 그래프의 루트 노드의 직접 자식 수가 이미\n"
              "DOT_GRAPH_MAX_NODES 를 초과하면 그래프가 전혀 표시되지 않습니다. 또한 그래프의 크기는 MAX_DOT_GRAPH_DEPTH에\n"
              "의해 더 제한될 수 있습니다.\n"
              "최소값: 0, 최대값: 10000, 기본값: 50.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "MAX_DOT_GRAPH_DEPTH 태그를 사용하여 dot 에 의해 생성되는 그래프의 최대 깊이를 설정할 수 있습니다. 깊이 값 3은 최대\n"
              "3개의 에지를 통하는 경로를 통해 루트에서 도달할 수 있는 노드만 표시됨을 의미합니다. 루트 노드에서 더 멀리 있는 노드는 생략됩니다. 이\n"
              "옵션을 1 또는 2로 설정하면 대규모 코드베이스의 계산 시간이 크게 줄어들 수 있습니다. 또한 그래프의 크기는\n"
              "DOT_GRAPH_MAX_NODES에 의해 더 제한될 수 있습니다. 깊이 0을 사용하면 깊이 제한이 없음을 의미합니다.\n"
              "최소값: 0, 최대값: 1000, 기본값: 0.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "GENERATE_LEGEND",
              "GENERATE_LEGEND 태그가 YES 로 설정되면 Doxygen은 dot에 의해 생성된 그래프의 다양한 상자와 화살표의 의미를\n"
              "설명하는 범례 페이지를 생성합니다.\n"
              "참고: 이 태그는 UML_LOOK이 설정되지 않은 경우, 즉 상속 및 협업 다이어그램에 Doxygen의 내부 그래픽 표현이 사용되는 경우에\n"
              "필요합니다.\n"
              "기본값은 YES입니다.\n"
              "이 태그는 태그 HAVE_DOT을 YES로 설정해야 합니다."
          );
  doc->add(
              "DOT_CLEANUP",
              "DOT_CLEANUP 태그가 YES 로 설정되면 Doxygen은 다양한 그래프를 생성하는 데 사용되는 중간 파일을 삭제합니다.\n"
              "\n"
              "참고: 이 설정은 dot 파일뿐만 아니라 임시 msc 파일에도 사용됩니다.\n"
              "기본값은 YES입니다."
          );
  doc->add(
              "MSCGEN_TOOL",
              "Doxygen 주석 내에서 \\msc 명령을 사용하여 메시지 시퀀스 다이어그램을 정의할 수 있습니다. MSCGEN_TOOL 태그가 비워진\n"
              "경우(기본값) Doxygen은 다이어그램을 생성하기 위해 내장 버전의 mscgen 도구를 사용합니다. 또는 MSCGEN_TOOL 태그로 외부\n"
              "도구의 이름을 지정할 수도 있습니다. 예를 들어 값으로 prog를 지정하면 Doxygen은 도구를 prog -T\n"
              "<outfile_format> -o <outputfile> <inputfile>로 호출합니다. 외부 도구는 출력 파일 형식 \"png\",\n"
              "\"eps\", \"svg\" 및 \"ismap\"을 지원해야 합니다."
          );
  doc->add(
              "MSCFILE_DIRS",
              "MSCFILE_DIRS 태그를 사용하여 문서에 포함될 msc 파일을 포함하는 하나 이상의 디렉터리를 지정할 수 있습니다(\\mscfile\n"
              "명령 참조)."
          );
}
